#----------------------------------------------------------------------
# This file was generated by encode_bitmaps.py
#
from wxPython.wx import wxImageFromStream, wxBitmapFromImage
from wxPython.wx import wxEmptyIcon
import cStringIO


def getAutoRefreshData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xf3IDATx\x9c\xb5\x94\xad\x16\xc30\x08\x85\xc9\xceD$\xb2\x8fX\x19Y\x89\
\xacD\xee\x11\'+\xe76\xb3\xb6\x94AB\xbb\x13\\\x7fr\xbf\xc0\x05\x12"B\xcf\xb8\
uU\x07\x80{\xf4\xc7\xe7\xb2\xbc\xf5\xbb\x011\xb5\xce\x852\x90\xe2\x0f\xe6*4\
\x0cX\x0f[\xe2\xf2\xe6-H5\x03K\x9c\x88\x92\x86\x10\x91\x0b\t{0\x96\x12\xaa\
\xb9\x8e\xe4\xb5\xa9\x97\xbaW\x1e\x0f\x1e\x06Hs\x89(-\xd3\xf1;g\xde\xcaw\n\
\xa0\x85\x01\x00Vq\xce\x0cc)\x90g\x1f\xe2z0 \xa6\xd5<}\x08\xe7\xfd[+\xdc\x0c\
Z\xa1K\x04`gpiU\xc8\x12\xbd\xa6\xfa\xbf\xddwQs\xd0j\x93Z^\xbb\xc1\x97\x00\
\x12$\x9fq>\xf6<g\xde\x80:\x9a&\xcbv\xd5\x06Z\xad\x0cp\xec\xbaS\xab\x82\xc4e\
tV\xd6\x90\x01\x04Jd\xad\x06o}[\x11\x9e\x03\xcbl\xbda\xff\x02|\x85~ 5\xf1\
\xd3\x80+\xd1}\xd0>\x19\xfd\x9b\x08\x1e\xad\xb3\x97\x00\x00\x00\x00IEND\xaeB\
`\x82' 

def getAutoRefreshBitmap():
    return wxBitmapFromImage(getAutoRefreshImage())

def getAutoRefreshImage():
    stream = cStringIO.StringIO(getAutoRefreshData())
    return wxImageFromStream(stream)

def getAutoRefreshIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getAutoRefreshBitmap())
    return icon

#----------------------------------------------------------------------
def getCopyData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xc8IDATx\x9c\xed\x95;\x0b\xc30\x0c\x84\xe5\xe2\xc1\xe3\xfd\xd4\x8c\x195\
v\xccO\xd5\xa8\xc1\x90\x0e!!\x0fI\xe4Q\x0f\x85\x1e\x08\x8c\x06}\xdc\xd9\xc2\
\t\x00\xb5\xd4\xab\xe9\xf4?\xe0\x8c\xb2\xd5\x14\x91\xd1\xea\x03HW\x01\xae\
\x03\xad\xba\xa9\x08|\x0b\xe0A\xafB\x92\xb5\x07"2jU*\xb9,\x83\xa73\x9bC\x80\
\xc1\x8d.\x04\xecU\xf2\x9b\xb4\xf6\x87^\x04\t#*\xb9l\xca\x93\xd6\x9eD:3\xba\
\x10`]\xf4\x1a\xbcwaAn9X\x03\xb5\xf6K\x11\x111\xf3\x06\xf2\xc8\xc1\x99\xf8\
\xccE\x9b\x87\x1c\xc5\x0b\xf8\xacL\x00\x80\xb4\xb7JD\xd4u\xe2\xc2=\xa8\xeb\
\x80\x99\x8dg7]\xe2c\x07\x91\xe6\x17\xd3\x04\x00\x0cft\x91\xccM\xfe\xa6~\xff\
\xc3i\x0e\xf8\x00\xb4\xedw\x96)\x01f=\x00\x00\x00\x00IEND\xaeB`\x82' 

def getCopyBitmap():
    return wxBitmapFromImage(getCopyImage())

def getCopyImage():
    stream = cStringIO.StringIO(getCopyData())
    return wxImageFromStream(stream)

def getCopyIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getCopyBitmap())
    return icon

#----------------------------------------------------------------------
def getCutData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xb6IDATx\x9c\xcd\x94\xd1\r\xc4 \x0cC\xcdM\xe0Q3BF`\xd4l\xd0\xfbi\xee*\
\xd4@@B\xc2R\xff\x1a\xbf\xe2\x98\x16\x92\xd8\xa9\xcfV\xf7c\x00fvm\x05\x00\
\x80\xaa\xbeBF\xf04@DB\xf3\x08\x9e\x06\x90,\xad\x91\x9b\xd7Z\xbb\xb3%[S7$YZs\
U-\xd1\xdct\x8b\xda8z\xe6S\x00\x8f\xc9w1\x8af\x1a\xf0\xa6\xd1\xd7\x03S;\x90;\
\x1a\xbd\x1f\x80\xacC\xc0\xf4\t\x9e\xd1\x98\xc9\xf5\x07/\x02z&\xb5\xf2\xf7\
\xce\x12\xc0\x07\xdd\xa8\xa7\xe8\xb2\x9d\xf1\xb3k\xe5\xcb\x151\x00\xfd\x13\
\x0e[\xf4\xcc\xd7\x8d\xbc\x9e\xcfX\xa2\xca\xa6j\x9a1\x8a\x94\xbe\x07\xab:s\
\xc9G\x01\xbe\xd4=_\xff?J\x99`\x00\x00\x00\x00IEND\xaeB`\x82' 

def getCutBitmap():
    return wxBitmapFromImage(getCutImage())

def getCutImage():
    stream = cStringIO.StringIO(getCutData())
    return wxImageFromStream(stream)

def getCutIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getCutBitmap())
    return icon

#----------------------------------------------------------------------
def getIconData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\
\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x02\\I\
DATx\x9c\xedV1\x92\xa40\x0c\xec\xbd\xdaG8p\xb0\xcfpp\xc1>\xc1\x01\x01\xcfPp\
\xc1>\x81\x80\x80g(\x98`\x9e@0\x81\x9f\xe1\x80`\x9e\xe0\x80*_\xc0\xda\xd8\
\xc63\xb0{uE\xb2\xaar\x01B\x12m\xa9%\xf3\xe2f\xe7q\xa2\xfc:\xf3\xe3\x00\xf0\
\n\x00\xc6\x18\x0c\xc3\x00\x00\x18\xfa\x01B\n\x00\xc0\xc7\x9f\x0f\xd8\xc9\
\x82\x88\xa0\x94\xc20\x0c0\xc6l\x82(\xa5\xd06m\xf4\x0bR\xda\xb7M\x0b\xdd\xe8\
\xdc\xd9\xcd\xce\xbb\xd9y\xa5\x94\x07\xe0\x89\xc8\xbb\xd9\xf9\xae\xef<\x00\
\x0f\xc0\x07\x1b\xdd\xe8\xa8+\x97nt\xb4s\xb3\xf3B\x8a\xaa]\x88\x1fV\x040\xde\
F\x0f\xc0\x0b)\xfcx\x1bc\x80\xf16n\x000s\xd4Yk7@\x03x\xdd\xe8\xe8\x1f\xe2\
\x971\x91\xa2\tY\x08\xd7rW5\x00\x9f$\xaef\xaa\xb4\x0b\xfa4n\x06 \xddM\x894\r\
@D\x9e\x99=3g:7;\xcf\xcc\x1b@\xcf\xd6k\xca\x07!\x05\x84\x14\xb8O\xf7H\xae\
\x9a\x04\xc2\xa6BDU\xdb=\xc9\xda\xd0\x18\x13?\x0e\x00\xd7\xcb\xb5\xeaDD`f0s\
\x04Y\x03uH\xd2\xf4\xa7\xb5\xc7\'!\xf78\x10R\x9e\xd65\xd8u}\x97\xf9\xd7\xb8\
\x153\xc0\x17\x861\x06\xba\xd1`\xe6X\x8a\xb6m\xbf\xbc\xa9\xb6Y|\xae\x97k\x9c\
\x03\xc6\x98x\xcf\xccy\x06jm\x97\xb6\x8d\xb5v7\x03J\xa9l\xb7DT\x9d\x03eg\xc4\
I\x18j\x99^\x89\x08v\xb213\xe1]:\xf1\x94R\xdb\xe9\x06\xa0\xeb;\x08)v\'\xe1\
\xcb\xcfa\xf4?\x83\xdf\' T@7\'\x000\x06\x08M\xe4\xe6\xba\xcd\xe9%8\x1d\xc0\
\xa1\x12\\/K:\xed\xb4<+\xb5\xae \xf7\t\x18\x86\xd5\xe6M\xe6\xef\x1f\xca\xdei\
5\xde\x9c\x07\xb6KHW\x0c\x9e\xad\x8dR\xeb\xfd\xa3\xf8\xbb\x00\xd2`\xcc\xcb\n\
:\xdd\x84i\xb8\xea\x88\x96\xe7\x12\xd0\xb7\x00\x84\xc0B.\x99X\x0f\x9b50\xf3\
\xfa\xacT\xee\x7f$\x03\x878p\x9f\x80\xf7\xdf\xfbv\xe5/\x01\xd1\xda\x86\x8f\
\xe4\x10\x00\xf1\x84PB\x1e\x89\xf0\x8f\x00\xde$0\xf4\xeb\xc7\x8cY\xb2R\x023&\
\x9fx\x95?\xf8\xad<\xe3\x80\xb59\xb9\x82^\xc8\x9c\x84]\xbf\xda\x05\xae\x94\
\xdd\xf3\xed.\xa8\xb5W\x19\xd4\xda\x9cp)\xe8=\x00\xbb\x93\xb0\xeb\x01\xe6<\
\xd5\xcc\xf9l\x17\xb2nsd\x10\xfd\xfc\x0f\x9c\x0e\xe0/\xa6u\x89KB\x8f8O\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getIconBitmap():
    return wxBitmapFromImage(getIconImage())

def getIconImage():
    stream = cStringIO.StringIO(getIconData())
    return wxImageFromStream(stream)

def getIconIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getIconBitmap())
    return icon

#----------------------------------------------------------------------
def getNewData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00uIDATx\x9c\xed\xd5\xbb\n\xc0 \x0c\x05\xd0\x9b\xe2\x90\xf1~\xb2\x9f\x9c1\
\x83`\xa7v\xf2EEJ\xa9\x01\x17\x03\x1e\x0c\x89\nI\xac\x8cc\xe9\xe9\x1b\x18\
\x89\xd0J\x9aYn\xe5I\xca\x14\x00\x00\x9e\xbc\xb8\xafAaf\xb9\x87L\x95\xc8\x93\
wo9\x05hP\x00\xedR>\x06<\xf9\xbd\x00 \xc6XD\xbe\xdf\xa6\x1b\xf8\x01\xd0}*\
\xaeaZ\x02\x90\x94\xda\x00\x8d\x86\xec/\xf3u\xe0\x04ND$:\xe8\xc5\xf5\x91\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getNewBitmap():
    return wxBitmapFromImage(getNewImage())

def getNewImage():
    stream = cStringIO.StringIO(getNewData())
    return wxImageFromStream(stream)

def getNewIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getNewBitmap())
    return icon

#----------------------------------------------------------------------
def getOpenData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xc9IDATx\x9c\xed\x951\x0e\xc3 \x0cE?U\x07F\x1f\xaaC\x8f\xe5#p\x9c\x0e=\
\x94G\x06$:\xa4T\x84\x04C\x11\x0c\x95\xfa\xa5\x88("\xefa;R\x0c\x11ae.K\xe9\
\x7fAO\xae\xa3/\x8aHL\xf7Ddj\xfb\x86*\x10\x91HD&]I\x96KS\xcc\xac\xcf4\xc1\
\xcbj\xaa-\xeamA\xb9\xb7\xcci\x05"\x12}\x00\x00\x0f\xc0\xc2*\x93j\xc9\x95\
\x19lp\xc0\xc3\x07\xc0\x87\xe3\n\x00\xcc\\=}C`w\x92\xf3\xb5\x1d\xa5E{\x98\
\xd6\xa6<\xddC.\xe1\x8fg\x1b~\xbfm-c\xe6\x8f\xa41\x03|\x05w\xce\x1d\x9e\xab\
\x15\x8c\xc0\xf3\xd3\x03J\x053\xe0\x802\xe46z\x8b\x06\xaf\n\xde/tKjpU0+\xbf\
\xff\xc3Y.x\x01\xfcgd\xb8c~\xd8\x9d\x00\x00\x00\x00IEND\xaeB`\x82' 

def getOpenBitmap():
    return wxBitmapFromImage(getOpenImage())

def getOpenImage():
    stream = cStringIO.StringIO(getOpenData())
    return wxImageFromStream(stream)

def getOpenIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getOpenBitmap())
    return icon

#----------------------------------------------------------------------
def getPasteData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xcfIDATx\x9c\xed\x95\xb1\x0e\xc3 \x0cD\x8f\x8a\x81\xd1\x9f\x9a\xb1\xa3G\
>\xd7#\x03\x12\x1d*R\x02\xa6A$\x0c\x95zR\x14@p\x0f0\x18CDX\xa9\xc7R\xf7?`Dv\
\xb4\xa3\x88\xa4\xb2NDfd\x9c\xe9\x9d\xa2\xda\x10\x00B|\xff\x9d2\xad\x1eP]\
\x81\x88$f\xde\xeb\xcc\x8c\x10?\xc6\xb9\\\xf5I\x1a\xe44\x06\xd9<\x1b\x97\xe5\
\x12\x90!C+\xa8\xa5m\xc9\xa8N\x87\xd6\xb3\xbc\x1dp\x84-\x06\x00@\x88\xcf\xa6\
\xcdY\x0f@\xa7_\xd8\xdd\x16\xec\xacG}\xea\xa7n\xb2\xb3~\xff\xca6\xa0=IS+\xa8\
\xb7)\xd7K\xe0%\x80f\xa4\xc5\xa6\x0b "\xa3]\x9a\x1c\xc8\x9e\xd90\xa0\x07\xd9\
6Qg?\x05\x00\x00f>\xe4\x16"=\x1d|S7\x9b\xde\xa5\xdf\x7f\xd1^\xf7\xdbLY\x05\
\x8av\xd9\x00\x00\x00\x00IEND\xaeB`\x82' 

def getPasteBitmap():
    return wxBitmapFromImage(getPasteImage())

def getPasteImage():
    stream = cStringIO.StringIO(getPasteData())
    return wxImageFromStream(stream)

def getPasteIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getPasteBitmap())
    return icon

#----------------------------------------------------------------------
def getRefreshData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xcaIDATx\x9c\xc5\x94\xc1\x11\x84 \x0cE\x93\x1d\x0b\xc8\xd1\x12=RBJ\xc8\
\x91\x12=\xd2\x81{\x91\x19\xcc\x12\x082\xcc\xfe\x9b"\xff\xc17\t\x12\x11\xac\
\xd4g\xa9;\x00l\xde\x0f\xcf\x94.\xfdn\'\xc2\xde>\xd7\rJ\xf3(\xd2\x84\xba\x01\
ys\xcd\xbc<y\x0f\xd2\xbcA\xcd\x9c\x99QC\x98\xd9\x84\xb8\xff\xc1\x11\x82+s-\
\xb4\xca\xd4\xba\xba\x15\x8f\x05w\x97i\x14\x81(\xf2\x88\xc3\x13S7\xa2\xb2jr\
\xfe#2\x01;\x11\xe6S\xbd1\xee\x02f\x8d\xb3\x96\x8f\x8a\xff\x02\xce\x94\xaeV\
\xa7N\x8d\x8a\x11\xa3\xb2\xd2\x86\x00\xdeqp\xaf\xcf5\xda\x11\xc2\xe3\xd9\x13\
\x8f\x0bP\x1b\r\xd6\xf8\xae\xc9\x9cEZ\xb5\x13\xeb\t;\x05\xb8\x8d~ \xbdf\x1c\
\x02\xbc\xd1\xf2F\xfb\x02O\x82o\x1e\xb4]1\xc3\x00\x00\x00\x00IEND\xaeB`\x82'\
 

def getRefreshBitmap():
    return wxBitmapFromImage(getRefreshImage())

def getRefreshImage():
    stream = cStringIO.StringIO(getRefreshData())
    return wxImageFromStream(stream)

def getRefreshIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getRefreshBitmap())
    return icon

#----------------------------------------------------------------------
def getSaveData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\x86IDATx\x9c\xed\x95\xb1\n\xc0 \x0cD\xb588\xde\'\xdf\';:\x14\xdaA\x04\
\xa9\x1a\xdb\xa2\x14\xa5\x07"\x04\xb9\xa7IT\r@\x8d\xd46\xd4}\t\x80)\x05\x9ds\
\xc7\x1b3\x00\xfa\x1a\xab\x9e\x80\x0c\xb3\xdf\xbd8\xd2\xb5$\xb3\x8duIQ\x04\
\x944\x07@\xd2\xfc\x80b\x9bF\x91JYcE\x03)\xffM\xc0\x1d\x83\x96\xba\x00\x86tQ\
z\xd1$-\xdaE\x004)?xiwI5\xa8\x169@\xf2\xc7\xeb\xa9\xf4\xffe~\x0e8\x01v84H\
\x1c6\xc2\x8f\x00\x00\x00\x00IEND\xaeB`\x82' 

def getSaveBitmap():
    return wxBitmapFromImage(getSaveImage())

def getSaveImage():
    stream = cStringIO.StringIO(getSaveData())
    return wxImageFromStream(stream)

def getSaveIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getSaveBitmap())
    return icon

#----------------------------------------------------------------------
def getTestData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x17\x08\x06\
\x00\x00\x00\x11!\x8f-\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x01\x15IDATx\x9c\xb5U\xbb\x11\x830\x0c\x95s)Rj\x04\x8f@A\xc18\x8c\xa2\x11\
\x18\x81qR\xa4\xf0\x08\x8c@I\xc1\x9d\xd3`\xb0\x85l\x8b\x1cQ\x83\x11\xf2\xfbH\
\x06\x0c"\xc2?\xe3\xf1Wt\x00xj\x8a\xe6y\xf6<\x87\x88F\xb3\xd7\x94Z$\x01_%\
\x12\x1dXkw`\xe7\\\x91 \xd4N\xd3$\x12\x9d\x1cXk\xfd\xfbs\x80\xbe\nM\\\xd6c\
\xdd\xb5\x8dHr\xeb\x90\x89\xe8\xd4\xd2\xc4\x01W\x1fBr\x11\xab\x0f!\xb9\xb8\
\xfd\x98r\x17\xbb\x83\x9cz\x80\xc3\xc1\xb2\xa6k)\xb8\x8b\xaa\x03\x0e\x18\xae\
\xa5\xe1\xc7.\xf62\xe7\\v\x13W\x1b\x9c\xc8\xf5i\x17T3\xe0@%\xf5<\xd4C\x0e\
\xa0W\xc0\x13\x02\xcd\xb7E\x03>\x0cCr\xaf\xd6\x13\xcf\xa1FDD\xf2)\xca\xb9\
\x90\x86,\x05W\x7f"\xd0\x80\xd7\xf2\xb1z\x91 v\x91\x03\x91\x9eK\xea\x0123@DC\
D\xbekG\x00\x00\x90\xde\xf0\xaem6\xe0~\xcfq\xf5\x00\x95\x1f\xce\xb6\xc9\x8f\
\xe3x\xca\xf7}\x19XM\x10\x13\t\xb9\xea\xd1V\x13\xfc\x1a_\xfc\x89l\x9f\xd7k\
\x04?\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTestBitmap():
    return wxBitmapFromImage(getTestImage())

def getTestImage():
    stream = cStringIO.StringIO(getTestData())
    return wxImageFromStream(stream)

def getTestIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTestBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeDefaultData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00QIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x1a\x06\xb0\xa0\x0b\xbcx\xf3\
\xe2?.\xc5\x1c,\x1c\x0c\x02\x02\x02\x8cx\r````\xb8q\xe3\x06\x86\xd8\x81\x03\
\x07\xb0\x1a:\xf0a@\xfd@d`\xc0\xed_\xa2\x0c\xe0`\xe1 \xc9\x05\x8cC?%Rl\x00\
\x00\xdc\x00\x0b\x9f\x8dZU\xfe\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeDefaultBitmap():
    return wxBitmapFromImage(getTreeDefaultImage())

def getTreeDefaultImage():
    stream = cStringIO.StringIO(getTreeDefaultData())
    return wxImageFromStream(stream)

def getTreeDefaultIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeDefaultBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeDialogData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00IIDATx\x9ccd``\xf8\xcf@\x01`\x81P?\xc8\xd4\xce\xc1\xc0D\x89\xed\x0c\
\x0c\x0c\x94\x1b\xc0\xc8@\x8d0\xb8p\xe5\x02Y\x9a\rt\x0c\x06A\x18\x8c$\x03\
\x0e\x1c8@\x1b\x17\xb0\x90b\x1b\xd1\x06888\x10m\x00\xc5I\x19\x00\xe6)\x0cc\
\xbf\x9c\xcc\xa1\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeDialogBitmap():
    return wxBitmapFromImage(getTreeDialogImage())

def getTreeDialogImage():
    stream = cStringIO.StringIO(getTreeDialogData())
    return wxImageFromStream(stream)

def getTreeDialogIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeDialogBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeFrameData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00:IDATx\x9ccd``\xf8\xcf@\x01`\x81P?\xc8\xd4\xce\xc1\xc0D\x89\xed\x0c\
\x0c\x0c\x94\x1b\xc0\xc8@\x8d0\xb8p\xe5\x02Y\x9a\rt\x0c\x06A\x18\x8c\x1a0,\
\x0c\xa08)\x03\x00\x90c\x07\x1f\xb3yvF\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeFrameBitmap():
    return wxBitmapFromImage(getTreeFrameImage())

def getTreeFrameImage():
    stream = cStringIO.StringIO(getTreeFrameData())
    return wxImageFromStream(stream)

def getTreeFrameIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeFrameBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeMenuData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00]IDATx\x9cc\x14\x10\x10`\x80\x81\x17o^\xfcg \x02p\xb0p0\x08\x08\x080\
2000\xb0\xa0K\xde\xb8q\x03\xaf\xe6\x03\x07\x0e\xa0\xf01\x0c\xc0\xa6\x08\x06\
\x1c\x1c\x1c0\xc4\x98\xf0ZG\x04\xa0\xd8\x00\xac^\xc0\xe6T\x92\x0c\x18\r\x83\
\xd10\xc0\xe5\x7f\xa2\x0c\xe0`\xe1 I3\x03\x03\x03\x03\x00l\xa5\x16\xbeals=\
\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeMenuBitmap():
    return wxBitmapFromImage(getTreeMenuImage())

def getTreeMenuImage():
    stream = cStringIO.StringIO(getTreeMenuData())
    return wxImageFromStream(stream)

def getTreeMenuIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeMenuBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeMenuBarData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00bIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4{P\x18\xc0\xf8\xe3\xcf\x8f\xff\
\xe4j\xe6`\xe1``a```\xb8q\xe3\x06\xc9\x9a\x0f\x1c8\xc0\xc0\xc0\xc0\x001\x00Y\
\x00\x19888\xe0\x14\x87\x81\x81\x0fD\xb8\x17\x90\x9d\x85\x0cp\x89\xc3\r\x981\
c\x06E.`d`` ;\x1a\x19\x18\x18\x18\x18G\xf3\x02\x03\x00DO\x13\x93\xa7\xebQk\
\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeMenuBarBitmap():
    return wxBitmapFromImage(getTreeMenuBarImage())

def getTreeMenuBarImage():
    stream = cStringIO.StringIO(getTreeMenuBarData())
    return wxImageFromStream(stream)

def getTreeMenuBarIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeMenuBarBitmap())
    return icon

#----------------------------------------------------------------------
def getTreePanelData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00CIDATx\x9c\xed\xd31\x0e\x800\x0cC\xd1W\x94\xa1\xf7?Q\x8e\x91\xa3t@\x82\t\
1\x131\xf6\xef\xfe^\xec\xb1\xceui2c\n\xa8\xaa\xcf\xe1\xcc\x04G\xb7\xfda\x0b\
\xb6\xe0\x17A\xf0\xce\xb2\xc3@\xfbLp\x03\xeer\x0c%l\xbc\t6\x00\x00\x00\x00IE\
ND\xaeB`\x82' 

def getTreePanelBitmap():
    return wxBitmapFromImage(getTreePanelImage())

def getTreePanelImage():
    stream = cStringIO.StringIO(getTreePanelData())
    return wxImageFromStream(stream)

def getTreePanelIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreePanelBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeRootData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00aIDATx\x9c\xed\x93\xcb\r\xc00\x08C\xa1\xea\x00\x1e\x83\xfd\xa7a\x0c6Ho\
\x88"\x88\x1aq\xado|l\xf1"\x85\x01\xd0Dw\xd54\xb3\x15k\x00\xdc\x06\x88\xc8kY\
U\xdb\xe5J\x0c\x80Dd\x9d\x1a\xfd\x82n\x901\xa2"\x92\x07D\x94\x93k< \x9bv\x0f\
W\x06d\xfd\x08\xdf\x11x\xfa\x17\xae\x91\x9b\x88\x1e\xba\x12*2\xab=\t\xe9\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getTreeRootBitmap():
    return wxBitmapFromImage(getTreeRootImage())

def getTreeRootImage():
    stream = cStringIO.StringIO(getTreeRootData())
    return wxImageFromStream(stream)

def getTreeRootIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeRootBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeSizerFlexGridData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00BIDATx\x9cc\x14\x10\x10`\x08\x08\t\xf8\xcf@&`\x8116\xac\xd9\xc0\x88,\
\x11\x10\x12\xf0\x1f]\x0c\x1d\x04\x84\x04\xfcg"\xd7f\x18\x18x\x03\x18G\x03q\
\xd4\x00j\x18@qBb\x14\x10\x10\xa0\xc8\x05\x00\xb4+\x16\xba\x9e\xe7\x8fF\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getTreeSizerFlexGridBitmap():
    return wxBitmapFromImage(getTreeSizerFlexGridImage())

def getTreeSizerFlexGridImage():
    stream = cStringIO.StringIO(getTreeSizerFlexGridData())
    return wxImageFromStream(stream)

def getTreeSizerFlexGridIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeSizerFlexGridBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeSizerGridData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00<IDATx\x9cc\x14\x10\x10`\x08\x08\t\xf8\xcf@&`\x8116\xac\xd9\xc0\x88M\
A@H\xc0\x7f|rL\xe4\xda\x0c\x03\xa3\x06000\x8eF\xe3p0\x80\xe2hd\x14\x10\x10\
\xa0\xc8\x05\x00M\x98\x16\xba|O\xcc\x02\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeSizerGridBitmap():
    return wxBitmapFromImage(getTreeSizerGridImage())

def getTreeSizerGridImage():
    stream = cStringIO.StringIO(getTreeSizerGridData())
    return wxImageFromStream(stream)

def getTreeSizerGridIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeSizerGridBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeSizerHData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00DIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x1a\x06\xb00000\x04\x84\
\x04\xfc\xa7\xc8\x00\x06\x06\x06\x86\rk60bS\x10\x10\x12\xf0\x1f\x9f\xdc\xc0\
\x87\xc1\xa8\x01T0\x80Q@@\x80\xa2\x84\xc48\xf43\x13\x00\xf5\xfe\x0c\x98\x979\
f\xc6\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeSizerHBitmap():
    return wxBitmapFromImage(getTreeSizerHImage())

def getTreeSizerHImage():
    stream = cStringIO.StringIO(getTreeSizerHData())
    return wxImageFromStream(stream)

def getTreeSizerHIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeSizerHBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeSizerVData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00?IDATx\x9cc\x14\x10\x10`@\x06\x01!\x01\xff\x19\x08\x80\rk60\xc2\xd8,\
\x84\x14\xa0\x03t\x0b\x98\x08\xd9F\x08\x8c\x1a\x80#\x16\x88\x89J\xbc\x06\x8c\
F#\x9d\r\xa08\x1a\x19\xd1\xb33\xa9\x00\x00&\x0c\x10mXtZ\x83\x00\x00\x00\x00I\
END\xaeB`\x82' 

def getTreeSizerVBitmap():
    return wxBitmapFromImage(getTreeSizerVImage())

def getTreeSizerVImage():
    stream = cStringIO.StringIO(getTreeSizerVData())
    return wxImageFromStream(stream)

def getTreeSizerVIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeSizerVBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeStaticBoxSizerHData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00dIDATx\x9c\xed\x92A\n\xc00\x08\x045\xe4\x01\xfb4\x0f>3\x07\x9f\xe6\
\x0f\xecU,\xb4IS\xe8\xa5s\x11\x16\x1c\x16\x91\x01\xd0\x0e\xad\x06\xee\x1e\
\x8f\x05\xee\x1e\x00xE\xd2\x89\x88D%l\x18\xd7\x06\xa2r+\xea5\xc8\rl\x18gyET\
\xa2\xd5\xe5<g8\x1dq\x95_\xf0\x82\x80\x01L=\xcc\xa5`\x87\xefop\x00N\x12$g%t;\
\xe1\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeStaticBoxSizerHBitmap():
    return wxBitmapFromImage(getTreeStaticBoxSizerHImage())

def getTreeStaticBoxSizerHImage():
    stream = cStringIO.StringIO(getTreeStaticBoxSizerHData())
    return wxImageFromStream(stream)

def getTreeStaticBoxSizerHIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeStaticBoxSizerHBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeStaticBoxSizerVData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00hIDATx\x9cc\x14\x10\x10`\xc0\x05>|\xf8\xf0_@@\x80\x11\xa7\x02\x06\
\x06\x06&B\x9a?|\xf8\xf0\x9f$\x03\x02B\x02\xe0\x1a\x905\x07\x84\x04\xfc\x87a\
\xa2\\\xc0\xc0\xc0\xc0\x80\xec\xfc\rk60nX\xb3\x01\xc3;8\r\x80i&;\x0c\x88\x05\
\xc3\xc0\x00\x16l\x82\xe8QE\xb2\x01\xd8\xa2\x0b\x97\xe1\x03\x1f\x06\x03o\x00\
\xc5\xb1\x00\x00\xf1\xda$S0&0\x03\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeStaticBoxSizerVBitmap():
    return wxBitmapFromImage(getTreeStaticBoxSizerVImage())

def getTreeStaticBoxSizerVImage():
    stream = cStringIO.StringIO(getTreeStaticBoxSizerVData())
    return wxImageFromStream(stream)

def getTreeStaticBoxSizerVIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeStaticBoxSizerVBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeToolBarData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x80IDATx\x9c\xed\x93\xbb\r\x840\x10D\x9f\x91\x03B\x97\xb1\x81\x83-\
\xc1%\x12\\\xb0\xe5\xb8\x0c\x97B\x80\x04\x11\x1fs\xd2!pr\x01\x13\xf9i4#\xdb\
\xabu!\x04Z\xd45\xa5\xff\xa2\xc0\x8d\xd38?\r\xf7\xbe\xc7\x03\x94Rn\x87s\xce\
\xc0\xe1\t\x12\x15\x89\xba\x19"\x8a\xc8\xce*\x8a\x1exU\xf3\x1f\xf8\xf5`\x9f\
\xa12\xccj\x1eN\xfcU\x90R\xaa\x8c+\xde\n\xcc\xec\xf2\x9a\xbf\xe4\x80\xc7c\
\x04p\xef.\xb0\x00\xb2\x8f\x1d_"\xe3\xe1\xc9\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeToolBarBitmap():
    return wxBitmapFromImage(getTreeToolBarImage())

def getTreeToolBarImage():
    stream = cStringIO.StringIO(getTreeToolBarData())
    return wxImageFromStream(stream)

def getTreeToolBarIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeToolBarBitmap())
    return icon

#----------------------------------------------------------------------
def getUndoData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x17\x00\x00\x00\x16\x08\x06\
\x00\x00\x00+v\x07\x05\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xb6IDATx\x9c\xed\x93\xb1\r\x830\x10E\x9f#\n\xca+3\x02\x03d\x80\x8c\xc1\
\x18)S\xa6L\xc9\x18\x8c\x91"%\x030\x82\xcb+]X"E\x04\x8a\x901\x08\x07\x89\x82\
W\x9e\xe4\xf7\xed\xbb\xb3\x11\x11\xb6\xe2\xb4\x99\xf9\x90\xaf\x96\xabj\xb7\
\x89<E\x0c\x90\xc5\xc4\xcf\xeb\x19\xe7\xe1\xf1\xb6C\x88\x88\x98\xa5r\x13\xda\
\xf3^\x9cg9\xce;\x00\x9c\x07uP5vqHP\xfe\x1b\x00p\x7f\xd9\xa1~\xbb|kUcg\x03&\
\xe5}\xc0\xf8\x96\xaa\xda\x95\x85P\xb7:+\x8f\x0e4tXDL\xdd*e!\xb3\x03\x8f\xde\
<F\xe8Uc\xf6\xfbC\x93z>\x85\xaavI\xab\xf8\x0f\xf6\xdb\xf3C\xbe\x8a\x0fa\xd1E\
H\xfdNS\x0c\x00\x00\x00\x00IEND\xaeB`\x82' 

def getUndoBitmap():
    return wxBitmapFromImage(getUndoImage())

def getUndoImage():
    stream = cStringIO.StringIO(getUndoData())
    return wxImageFromStream(stream)

def getUndoIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getUndoBitmap())
    return icon

#----------------------------------------------------------------------
def getRedoData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x17\x00\x00\x00\x16\x08\x06\
\x00\x00\x00+v\x07\x05\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xbfIDATx\x9c\xed\xd4/\x0e\xc20\x14\xc7\xf1\xef\xc8\xc4\x13\x13=\x06r\
\x129\x81@"v\x00\x04\x87B\xec\x08\x88\x1d\x00\xd1#Lr\x8c\'\x10uE\x90\x92\x10\
6\xda4, \xf6\x93M\xf3y/\xaf\x7f\nc\x0cse5\x9b\xbc\xe0_\xc7U\xd5\xcf\x86\xa7\
\x14(s\xb1\xdda\x83\x88\xd0\x9f\xac7\xc6\x14c\xfb\x8b\x94{\x1e\xd0\xa6\xad\
\x91J\x90R\x00\x90\n\xdc\r\xfa\xce2V \xda\xb9\xaa\xfa\xa6\xad\x01\xb0\xe7\
\xe1\xb9\xbe?687\r\'\xe1\x8f\x02\x8e\xe1r}A\xfa\xcez`\x12\x86\xc8\x81\xaa\
\xaa\xaf\xb7\xeb78\xe4\x13\x0c\x91\x99\x87Y\xc7\x90\xa9\xfc\xee\x11\xe5v\x9c\
\x84\x87\x02)\xafq,I\xf7<7\xff\xf9q-xv\xee"\x1b=\x87\xa0\x01\x91\x87\x00\x00\
\x00\x00IEND\xaeB`\x82' 

def getRedoBitmap():
    return wxBitmapFromImage(getRedoImage())

def getRedoImage():
    stream = cStringIO.StringIO(getRedoData())
    return wxImageFromStream(stream)

def getRedoIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getRedoBitmap())
    return icon

#----------------------------------------------------------------------
def getToolDefaultData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00QIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x1a\x06\xb0\xa0\x0b\xbcx\xf3\
\xe2?.\xc5\x1c,\x1c\x0c\x02\x02\x02\x8cx\r````\xb8q\xe3\x06\x86\xd8\x81\x03\
\x07\xb0\x1a:\xf0a@\xfd@d`\xc0\xed_\xa2\x0c\xe0`\xe1 \xc9\x05\x8cC?%Rl\x00\
\x00\xdc\x00\x0b\x9f\x8dZU\xfe\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolDefaultBitmap():
    return wxBitmapFromImage(getToolDefaultImage())

def getToolDefaultImage():
    stream = cStringIO.StringIO(getToolDefaultData())
    return wxImageFromStream(stream)

def getToolDefaultIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolDefaultBitmap())
    return icon

#----------------------------------------------------------------------
def getToolDialogData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00IIDATx\x9ccd``\xf8\xcf@\x01`\x81P?\xc8\xd4\xce\xc1\xc0D\x89\xed\x0c\
\x0c\x0c\x94\x1b\xc0\xc8@\x8d0\xb8p\xe5\x02Y\x9a\rt\x0c\x06A\x18\x8c$\x03\
\x0e\x1c8@\x1b\x17\xb0\x90b\x1b\xd1\x06888\x10m\x00\xc5I\x19\x00\xe6)\x0cc\
\xbf\x9c\xcc\xa1\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolDialogBitmap():
    return wxBitmapFromImage(getToolDialogImage())

def getToolDialogImage():
    stream = cStringIO.StringIO(getToolDialogData())
    return wxImageFromStream(stream)

def getToolDialogIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolDialogBitmap())
    return icon

#----------------------------------------------------------------------
def getToolFrameData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00:IDATx\x9ccd``\xf8\xcf@\x01`\x81P?\xc8\xd4\xce\xc1\xc0D\x89\xed\x0c\
\x0c\x0c\x94\x1b\xc0\xc8@\x8d0\xb8p\xe5\x02Y\x9a\rt\x0c\x06A\x18\x8c\x1a0,\
\x0c\xa08)\x03\x00\x90c\x07\x1f\xb3yvF\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolFrameBitmap():
    return wxBitmapFromImage(getToolFrameImage())

def getToolFrameImage():
    stream = cStringIO.StringIO(getToolFrameData())
    return wxImageFromStream(stream)

def getToolFrameIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolFrameBitmap())
    return icon

#----------------------------------------------------------------------
def getToolMenuBarData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00bIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4{P\x18\xc0\xf8\xe3\xcf\x8f\xff\
\xe4j\xe6`\xe1``a```\xb8q\xe3\x06\xc9\x9a\x0f\x1c8\xc0\xc0\xc0\xc0\x001\x00Y\
\x00\x19888\xe0\x14\x87\x81\x81\x0fD\xb8\x17\x90\x9d\x85\x0cp\x89\xc3\r\x981\
c\x06E.`d`` ;\x1a\x19\x18\x18\x18\x18G\xf3\x02\x03\x00DO\x13\x93\xa7\xebQk\
\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolMenuBarBitmap():
    return wxBitmapFromImage(getToolMenuBarImage())

def getToolMenuBarImage():
    stream = cStringIO.StringIO(getToolMenuBarData())
    return wxImageFromStream(stream)

def getToolMenuBarIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolMenuBarBitmap())
    return icon

#----------------------------------------------------------------------
def getToolMenuData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00]IDATx\x9cc\x14\x10\x10`\x80\x81\x17o^\xfcg \x02p\xb0p0\x08\x08\x080\
2000\xb0\xa0K\xde\xb8q\x03\xaf\xe6\x03\x07\x0e\xa0\xf01\x0c\xc0\xa6\x08\x06\
\x1c\x1c\x1c0\xc4\x98\xf0ZG\x04\xa0\xd8\x00\xac^\xc0\xe6T\x92\x0c\x18\r\x83\
\xd10\xc0\xe5\x7f\xa2\x0c\xe0`\xe1 I3\x03\x03\x03\x03\x00l\xa5\x16\xbeals=\
\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolMenuBitmap():
    return wxBitmapFromImage(getToolMenuImage())

def getToolMenuImage():
    stream = cStringIO.StringIO(getToolMenuData())
    return wxImageFromStream(stream)

def getToolMenuIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolMenuBitmap())
    return icon

#----------------------------------------------------------------------
def getToolPanelData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00CIDATx\x9c\xed\xd31\x0e\x800\x0cC\xd1W\x94\xa1\xf7?Q\x8e\x91\xa3t@\x82\t\
1\x131\xf6\xef\xfe^\xec\xb1\xceui2c\n\xa8\xaa\xcf\xe1\xcc\x04G\xb7\xfda\x0b\
\xb6\xe0\x17A\xf0\xce\xb2\xc3@\xfbLp\x03\xeer\x0c%l\xbc\t6\x00\x00\x00\x00IE\
ND\xaeB`\x82' 

def getToolPanelBitmap():
    return wxBitmapFromImage(getToolPanelImage())

def getToolPanelImage():
    stream = cStringIO.StringIO(getToolPanelData())
    return wxImageFromStream(stream)

def getToolPanelIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolPanelBitmap())
    return icon

#----------------------------------------------------------------------
def getToolRootData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00aIDATx\x9c\xed\x93\xcb\r\xc00\x08C\xa1\xea\x00\x1e\x83\xfd\xa7a\x0c6Ho\
\x88"\x88\x1aq\xado|l\xf1"\x85\x01\xd0Dw\xd54\xb3\x15k\x00\xdc\x06\x88\xc8kY\
U\xdb\xe5J\x0c\x80Dd\x9d\x1a\xfd\x82n\x901\xa2"\x92\x07D\x94\x93k< \x9bv\x0f\
W\x06d\xfd\x08\xdf\x11x\xfa\x17\xae\x91\x9b\x88\x1e\xba\x12*2\xab=\t\xe9\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getToolRootBitmap():
    return wxBitmapFromImage(getToolRootImage())

def getToolRootImage():
    stream = cStringIO.StringIO(getToolRootData())
    return wxImageFromStream(stream)

def getToolRootIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolRootBitmap())
    return icon

#----------------------------------------------------------------------
def getToolCheckBoxData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\x08\x06\x00\
\x00\x00\x8d2\xcf\xbd\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00?IDATx\x9cc\xfc\xf1\xe7\xc7\x7f\x06\x02\x80\x83\x85\x83\x81\x85\x81\x81\
\x81\xe1\xc6\x8d\x1b\x84\xd420\x11Rp\xe0\xc0\x01\xe2\x14\x12m\xe2 P\xc8\x02c\
\xc0|\x87\x0b0200\x10\x0cp\x06\x06\x06\x06\x00b\x8b\x0c\x1dT!\xdd>\x00\x00\
\x00\x00IEND\xaeB`\x82' 

def getToolCheckBoxBitmap():
    return wxBitmapFromImage(getToolCheckBoxImage())

def getToolCheckBoxImage():
    stream = cStringIO.StringIO(getToolCheckBoxData())
    return wxImageFromStream(stream)

def getToolCheckBoxIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolCheckBoxBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeToolData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00^IDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x1a\x06\xb0\xa0\x0b\xbcx\xf3\
\xe2?>\r\x1c,\x1c\x0c\x02\x02\x02\x8c8\r````\xb8q\xe3\x06V\xcd\x07\x0e\x1c\
\xc0\x10\xa3\xbe\x17p\xd9\xe8\xe0\xe0\x80U\xcd \x8c\x05d\x80\xcb\xd9\x04\r\
\xc0\x16\xdaD\x1b\xc0\xc1\xc2A\xb4f\x06\x06\x06\x06\xc6\x01\xcf\x0b\x00"\x92\
\x0fc\x04\xf8\xbb\xc7\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeToolBitmap():
    return wxBitmapFromImage(getTreeToolImage())

def getTreeToolImage():
    stream = cStringIO.StringIO(getTreeToolData())
    return wxImageFromStream(stream)

def getTreeToolIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeToolBitmap())
    return icon

#----------------------------------------------------------------------
def getToolToolData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\t\x00\x00\x00\t\x08\x06\x00\
\x00\x00\xe0\x91\x06\x10\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00LIDATx\x9c\x95\xd0\xb1\r\xc0 \x10C\xd1GD\xc1X\x8c\xce\x18\x8cB\x11)\
\xa9\x12!qB\xc9\xaf\xae\xf0\xd9\x96\xd38\xc7eC\xc9E\x86\xde{(h\xad\x81c\xe7\
\xf2\x90\xa3O\xa8\xb5\xbe\xf7\'\xa7\xffqs\xc4"\x9a\xbbD$lw\x82\x1b\xd7\x84\
\x0f\xdfLT\x19\x1d\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolToolBitmap():
    return wxBitmapFromImage(getToolToolImage())

def getToolToolImage():
    stream = cStringIO.StringIO(getToolToolData())
    return wxImageFromStream(stream)

def getToolToolIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolToolBitmap())
    return icon

#----------------------------------------------------------------------
def getToolMenuItemData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x0c\x00\x00\x00\t\x08\x06\
\x00\x00\x00\x06\xb8\xcdT\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00NIDATx\x9cc\xfc\xf1\xe7\xc7\x7f\x06"\x01\x07\x0b\x07\x03\x0b\x03\x03\
\x03\xc3\x8d\x1b7\x08*>p\xe0\x00\x03\x03\x03\x03\x03\x13\xb1\xa6\xc3\x00\x0b\
6S\xd0\x81\x83\x83\x03\x9cM\xb2\r\x949\t\xd9j\xbc\x1ap\xb9\x1d\x1b`d`` :\x1e\
\x18\x18\x18\x18\x00h[\x0f\xdf\xbb\xf3\x12\xf4\x00\x00\x00\x00IEND\xaeB`\x82\
' 

def getToolMenuItemBitmap():
    return wxBitmapFromImage(getToolMenuItemImage())

def getToolMenuItemImage():
    stream = cStringIO.StringIO(getToolMenuItemData())
    return wxImageFromStream(stream)

def getToolMenuItemIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolMenuItemBitmap())
    return icon

#----------------------------------------------------------------------
def getToolFlexGridSizerData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00BIDATx\x9cc\x14\x10\x10`\x08\x08\t\xf8\xcf@&`\x8116\xac\xd9\xc0\x88,\
\x11\x10\x12\xf0\x1f]\x0c\x1d\x04\x84\x04\xfcg"\xd7f\x18\x18x\x03\x18G\x03q\
\xd4\x00j\x18@qBb\x14\x10\x10\xa0\xc8\x05\x00\xb4+\x16\xba\x9e\xe7\x8fF\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getToolFlexGridSizerBitmap():
    return wxBitmapFromImage(getToolFlexGridSizerImage())

def getToolFlexGridSizerImage():
    stream = cStringIO.StringIO(getToolFlexGridSizerData())
    return wxImageFromStream(stream)

def getToolFlexGridSizerIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolFlexGridSizerBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeMenuItemData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00cIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x81\x81\x81\x05\xc6x\xf1\xe6\
\xc5\x7fb5q\xb0p0\x08\x08\x080\xa2\x18\xc0\xc0\xc0\xc0p\xe3\xc6\r\x82\x9a\
\x0f\x1c8\x80\xc2\xa7\x9e\x17\xf0\xd9\x02\x03\x0e\x0e\x0e\x18b\x14\xbb\x806^\
\xc0\xe6T\xa2\x0c\xc0\xe5w\xa2\x0c\xe0`\xe1 Y3\x03\x03\x03\x03\xe3\x80\'e\
\x8a\r\x00\x00GI\x0fc!\x9f\xc7\x01\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeMenuItemBitmap():
    return wxBitmapFromImage(getTreeMenuItemImage())

def getTreeMenuItemImage():
    stream = cStringIO.StringIO(getTreeMenuItemData())
    return wxImageFromStream(stream)

def getTreeMenuItemIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeMenuItemBitmap())
    return icon

#----------------------------------------------------------------------
def getToolToolBarData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x08\x08\x06\
\x00\x00\x00\xf0v\x7f\x97\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00lIDATx\x9c\xa5\x91\xb1\r\x800\x0c\x04\x0f\x94\x82Q\\Px\x84\x8c\x98\
\x82\xc2\xe3d\x8c\x8cB\x81\x04U\x02\x01\x89\x88p\x95\xcf/[\x96<\xac\xdb\xba\
\xd3\xc9\xe4&\x1c@J\xe9\xf3p\x8c\x11\x8017dVd\xd6\x12\x88("\xa7\xab(z\xf1\
\xcc\xc8O\\.l\tU`V{\xb8\xf9c\x81\xf7\xbe\nZ^\x16\x98Y\xf3\xcc7\x06\xa0\xfb\
\x8d\x00\x07:\x91\x1c\xf1\xcb\xec\x06\xb4\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolToolBarBitmap():
    return wxBitmapFromImage(getToolToolBarImage())

def getToolToolBarImage():
    stream = cStringIO.StringIO(getToolToolBarData())
    return wxImageFromStream(stream)

def getToolToolBarIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolToolBarBitmap())
    return icon

#----------------------------------------------------------------------
def getToolChoiceData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x0c$\xbf\x95\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x91IDATx\x9c\xbd\x94=\x0e\x80 \x0c\x85\x1f\xa6C\x8f\xc2\xe0\xc0\xfd\
\'\x8e\xc0\xe0\xc0Q\x18Lt\xc2(P\x84\xc4\xfa-$M\xd3\xd7_L\xda\xd3\x01%\x98\
\x18\x04\x001F-\r,Z\x81\xbd\xf7}\x01\xb7\xbaO\x84\xd4*\xc8P\xcb\xe8V\x87\xb0\
\x85\xeb\xbdc\xad\x15\x831q\xe5\xdf\x14xcf)\xaa\x16\xdd\xb3\xceU\x8c\x90\x87\
Z"\xb6\xe8+\x1e\x02\xad\x9eKv)\xe3\xae\xc0\x08L<\xe5\xff\x10he_\xda%\x1f\t\
\xf5;\xf8\xef\xd0F\x876\x8b\x01\xa0\xf6]\x03\xc0\t\'\xec0\xc5\xed<\xbeO\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getToolChoiceBitmap():
    return wxBitmapFromImage(getToolChoiceImage())

def getToolChoiceImage():
    stream = cStringIO.StringIO(getToolChoiceData())
    return wxImageFromStream(stream)

def getToolChoiceIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolChoiceBitmap())
    return icon

#----------------------------------------------------------------------
def getToolSpacerData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00/IDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b&\x06|\xf8\xf0\xe1?14\x0c0R=\
\x0c\xd0m $?\xea\x02Z\xba`\xe0\xd2\x01\xa9\x00\x00`~>\'\xaa4\xf4\x95\x00\x00\
\x00\x00IEND\xaeB`\x82' 

def getToolSpacerBitmap():
    return wxBitmapFromImage(getToolSpacerImage())

def getToolSpacerImage():
    stream = cStringIO.StringIO(getToolSpacerData())
    return wxImageFromStream(stream)

def getToolSpacerIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolSpacerBitmap())
    return icon

#----------------------------------------------------------------------
def getToolStaticTextData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x16\x00\x00\x00\r\x08\x06\
\x00\x00\x00\xad\xa5\x9ec\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00kIDATx\x9c\xd5SA\n\xc00\x08\xd3\xb1\x07\xe4\xff\xaf\xcc\x0f\xdcIp%\
\x0e\xdaQ\xc6r3\xda$\nu\x00\xb6\x03\xc7\x16\xd5O\x84I\xc6S\xbd,\xfc\x16R\x98\
d\x00p\x95\x92d\xa8mFn*q\x1aVS\xc5I\xe1\x1c43\x1b\x87\x93\xefP\xfbg\x97lf\
\x13\x85\x9bpM\xab\x8c\xba\xbez/\x13w\xa8\xa7Q\xe7\xaa\xa6\xfe\xbb/}\x01*\
\x1bS\x8a\xc2\x15\xd1\x9d\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolStaticTextBitmap():
    return wxBitmapFromImage(getToolStaticTextImage())

def getToolStaticTextImage():
    stream = cStringIO.StringIO(getToolStaticTextData())
    return wxImageFromStream(stream)

def getToolStaticTextIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolStaticTextBitmap())
    return icon

#----------------------------------------------------------------------
def getToolTextCtrlData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x0c$\xbf\x95\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00HIDATx\x9cc\x9c0e\xc2\x7f\x06\x1a\x02\x16\x06\x06\x06\x86\x82\x9c\
\x02\x9a\x18\xfe\xe3\xcf\x0f\x88\x050\x0e5\xc1\x8d\x1b7\x18\x18\x18\x18\x18\
\x98\xa8j*\x160j\xc1\xa8\x05\xa3\x16\x0c\x07\x0b\xe0e\x11\xac\xec\xa0\x89\
\x05\xd4.\xe8\x90\x01\x00\x81\x02\x11\xfb\x02\xab> \x00\x00\x00\x00IEND\xaeB\
`\x82' 

def getToolTextCtrlBitmap():
    return wxBitmapFromImage(getToolTextCtrlImage())

def getToolTextCtrlImage():
    stream = cStringIO.StringIO(getToolTextCtrlData())
    return wxImageFromStream(stream)

def getToolTextCtrlIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolTextCtrlBitmap())
    return icon

#----------------------------------------------------------------------
def getToolButtonData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x0c$\xbf\x95\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x84IDATx\x9c\xc5\x941\n\xc0 \x0cE\x9f\xc5\xc1\xc3t\xe8\xfd\'\x8f\
\x90\xc1\xc1\xa38\x14\xda\xc9B\xa5\xc6B\r\xfd\xe0`\x82\xff\x91\x18\xe2\xca^\
\x0e\x8c\x14|\xc0\x03\xe4\x9c\xad\x18,V\xc61F[@\x95\n\xd8\xd6\xedv\xda\x9cv\
\xaf\xf2\x9a\xb9$\x19\xc6\xb48Lh\x91f\xfe\x19\xd0k\xcb4\x80$A\x92\xa8\xa0\
\x7f\xa7\xe8\xad\xb4*\xbaS\xf4\xf4H\xfb\xcc\x9e\xba\x80\x91a\x9b3\x1b\xd3\
\x91\xae\n\xea\xee\x98-\x07\x98\xadk\x80\x13\xd4\x8e1G9C\xf0\xc0\x00\x00\x00\
\x00IEND\xaeB`\x82' 

def getToolButtonBitmap():
    return wxBitmapFromImage(getToolButtonImage())

def getToolButtonImage():
    stream = cStringIO.StringIO(getToolButtonData())
    return wxImageFromStream(stream)

def getToolButtonIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolButtonBitmap())
    return icon

#----------------------------------------------------------------------
def getToolBitmapButtonData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x18\x08\x06\
\x00\x00\x00\xe0w=\xf8\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x02\x05IDATx\x9c\xb5\x96-\x90\xda@\x18\x86\x9f\xebD\xac\xa8X\x81\x88DT\xac\
\xa8@"N *"N *NT \x10\x88\x13\x88\x8a\x08\x042\xa2"\x02\x11\x89\xa8@\x9c@T ND\
 "*"\x10\x11\x15\x11\'VT\xac@|"3\xad\xa0i\xa7\x1d\x08\xe1\xa6\xbcr\'\xfb>\
\xfb~\xfb\xf3\xe5F*\xf9\xc1\x95\xa4<\x85\x07P\x14\xc5\xb5\x18\xbc\xba\x96q\
\x9a\xa6\xd7\x05\xd4\xf2\xda|d\x8c9:\xde\xa6\xb4\x8d\t\x8c1\xbf\xcde/\xe4_s\
\x9csg\xc1\xad\x00\xf5\xe4l\x9b\x11N\'\xc8\xf7\x04\xe3g`\x97l\x1e\xe7\x8cF\
\xc3V\x90\xc6\x04\xd96\xc3\xf7\x15\xe1\x83Aw\xfa(=@w4\x83[\x9f\xe8c\x9f\xd1\
\x87\xd1Y\xc8Q@=!^\xc4\xf8^\x8a\xee\x0c\xc0\xeb\x82\xa7\xe1u\x80\xf2\x14Zk\
\xc2\xb1\xcf\xfd\xfb\xfb\x97\'\x98\x8e\x03P\x1a\x94\x7f\x18\xa8\x04*A*\x85\
\xf2@w\x14Z\xab\xc6\x14\x8d\x00\x91\x83\xe1A\n<\x8d\xc8a\x93\x05\x05\x9e\xc2\
\xd7r\xda\xe0\x14\xa0>~\xd1b\xfd\x0b P9\x90\x12*\xfb\'\x89s\xac\x1e\xd3\xcb\
\x01\xb5\x92$A*\x0e\x86\x9eB\xa4\x04\x1cT\x82\xb5\x96\xf2\xd91\x8f\xe2\xbf\
\x16\xf5\xaf\x1a/\x9aR\n%\x02(d_B\xe5\x10qXk\x91\xbd\x10%\x05\x9b\xa7\xa41\
\xc1I@Q\x14$IL\x9e\xa5t\xdfd\xc4\xb3\x01\xce9\xcag\xcb\xfcS\x8a\xee\x186Oi\
\xe3\xea\xe1l\x89\x96\xf8]C8\x8b(\xf7}\xa6Q\xc6f+,?oX\x7fY\x9f5oL\x000\xbc\
\x0bX\xad\xd6\xe4yN8\x9b\xd3\xeb\xf5\x08\xc3\x10\xadu\xeb\'\xfed\x82\xe0]\
\xc0\xe4a\xca\xf0. \xdb\xa6\x18cX.\x97Xk/\xea\x1f\'\x01\xd6Z\xa2h\xced2\xa5\
\x7f;\xa0\xd8\x15h\xad[\x1b\xd7:Y\xa2|\x97\xd3{\xdb\xa3\xfc6\xc1\xf7}\xfa\
\xfd\x01\xf1"\xbe\x18p\xb6\xe1\x88\x08EQ0\x1a\x8f.6\x873\x9b\x9c\xef\xf2\x17\
\x99\x1e\x05\xd4=\xf4\x7f\xeb\x06\xb8\xdao\x0b\xc0O\x923\xdby\x95O\x1dg\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getToolBitmapButtonBitmap():
    return wxBitmapFromImage(getToolBitmapButtonImage())

def getToolBitmapButtonImage():
    stream = cStringIO.StringIO(getToolBitmapButtonData())
    return wxImageFromStream(stream)

def getToolBitmapButtonIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolBitmapButtonBitmap())
    return icon

#----------------------------------------------------------------------
def getToolRadioButtonData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x0b\x00\x00\x00\x0b\x08\x06\
\x00\x00\x00\xa9\xacw&\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\x86IDATx\x9cu\xd0\xa1\x11\xc30\x0c\x85\xe1_\x9e@  C\x14\x04\x1ad0\x8f\
\xa0\xc1\n\x02\x03:D\x80\x817HQZUQ\x1f\xb1\xcf\xf7=\xebN\xa2\xaa\xc4\xb4\xd6\
N3\x93\xf8^2\xe8\xcf\xbf\xd8A\xb2B\xc9\xe0\xfe\xda\xd3B\xc9 \x90\x16\xc4\xcc\
n\xd0gy,\x98\x19\x00\xa2\xaa\x1c\xfd8\x01\xb6\xe7\x86N\xdf\xed\x8c>\xa8k\x05\
`\x9ef)\xd7\x05\xa0\xae\x95\xd1G\n??_\xf1\x13"\xbca_\x88\xf0gu\x11D\x08\xf0\
\x06\x99\xd2L\tb\x83\xa4(\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolRadioButtonBitmap():
    return wxBitmapFromImage(getToolRadioButtonImage())

def getToolRadioButtonImage():
    stream = cStringIO.StringIO(getToolRadioButtonData())
    return wxImageFromStream(stream)

def getToolRadioButtonIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolRadioButtonBitmap())
    return icon

#----------------------------------------------------------------------
def getToolSpinButtonData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\t\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\xc4HUC\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\x8dIDATx\x9c\x9d\x90\xb1\r\xc30\x0c\x04_\x86\x07\xf8ARx\x04\r\xe4B\xa3\
\xa8\xf0@\x1aC#\xa8P\xc1\xd2\x85\x01\xa6\xa2c\xcb\x91\x1d\x84\xc07\xe4\x01\
\xff|G\x12O3\xb4\x8bR\x8b\xdeB\xa5\x16\xcd9CD\xf4+d\x00\x00\xc4%\x9e\xc0\xa1\
\x05\x00\xc0{\x7f\x02G;\xa4\x94\xfa\xc9\xd7mU\x00\xb7r\x7fU\xd0\xb5\xeb).\
\xf1c\xd7~g\x8f\x849\x80\xa4\xdb3\xb5\xe0\xf4\x9a@\xd2u3]\xea \xb9\xeb\x98\
\xe3\xb8\xbfT "j66?\xf5\xf4\x06%\x06t\x8fl^\xaef\x00\x00\x00\x00IEND\xaeB`\
\x82' 

def getToolSpinButtonBitmap():
    return wxBitmapFromImage(getToolSpinButtonImage())

def getToolSpinButtonImage():
    stream = cStringIO.StringIO(getToolSpinButtonData())
    return wxImageFromStream(stream)

def getToolSpinButtonIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolSpinButtonBitmap())
    return icon

#----------------------------------------------------------------------
def getToolStaticBoxData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x16\x08\x06\
\x00\x00\x00\xda}\\\x88\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\xa2IDATx\x9c\xedU1\n\xc30\x0c\x94\x82\x1f\xa0!\x83\x9f\xa8gx\xc8\
\x032t\xf0\x13=d\xd0\x98\xa1\xe0N*IH\xe5 ZB\xc17\xd9`\xdd\xe9\xc4\t#\x11\x81\
\x05\x11\xa9D\x84\xe6#\x03\x83\xb7\xf0+\x02\xda\xbd\x88T\xaf@HS\xda\x1533\
\xc41\x9a#)K\xa99\xe7&93C\xd0\x83B\xc9\xb7\xb3W\x17z\x8fc\xc4\xb2\x94K\xae\
\xc2\x91x\x0bk4-\x97iJ\xf5\xed\xe0\x8c\xf8,9\x9eD\xdd\x93\xa2O]z\xf6\xe1\xde\
=\xe8\x02]\xa0\x0b\xfc\x89\x00\xce\x8f\xd9\xfd[\xb5\xc0\xcc\x80\xebs\xfd\x99\
\x00\x00\xc0\x0b\xb9:<\xe6\x18V\xd1\xdf\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolStaticBoxBitmap():
    return wxBitmapFromImage(getToolStaticBoxImage())

def getToolStaticBoxImage():
    stream = cStringIO.StringIO(getToolStaticBoxData())
    return wxImageFromStream(stream)

def getToolStaticBoxIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolStaticBoxBitmap())
    return icon

#----------------------------------------------------------------------
def getToolRadioBoxData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x16\x08\x06\
\x00\x00\x00\xda}\\\x88\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x01\x05IDATx\x9c\xc5\x94!\x12\x830\x10E\x7f:\x1c \x02\xc1Q\x10=\xd0JD\
\x05\x12Q\x81\xac\xa8\xe0@\x15HD\x0f\x11\x11\xb1\x12\xd1\x99T\x85\x06\x1a\
\x926\xd0\xe9*\x92a\xdf\xcb\xeel"\xa4\x94\x08\x053\x1b)\xa5\x08\xfe\x14\x88C\
j\xe2.\x02{zf6\xa9\x82\xac97\xb3d"B\x91\x17\xc1\x96(\xadL\xd7uQ8\x11!\xb3\
\x1f6,\xdc\xed\xbd\xad\xc2\xae\x8b\xbc\x10J\xab\x8f\xaa\xca\x96`7B\xad\x89U\
\xd9\x9c\x1b3U\xe0\x03\xfb&\'e\xa2\xfe3E\xee)\xeb\xba6\xbe\xfdM\x82%\xdc\x95\
\xec&p\xe0\xb3\xf5.\x02\x17>\xdc\x87M\x927\xc1\x12\x0e`\x93d&\xf0\xc1m\xa4Jf\
\xf7\xa0m[\xa1\xb42\xd5\xa9B\x7f\xeb!\xf3\xd7K\xcb\x9a1>F\x00\xf1K\xb6Z\x81\
\x9b\\\x1eK\xb0\xe6\t^\x1e\xcb\xaf\xe1^\x81O\x92\n_\x15,%\xa9\xf0\xa0\xc0\
\x85\xa6\xc2\xa3\x82\xadp\x00\x10\x97\xeb%\xf9\x19\x88\x05\x11A\x8c\x8f\xf1g\
\x02\x00x\x02J\xca\x8a\xcbs\xe5\x05\x0f\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolRadioBoxBitmap():
    return wxBitmapFromImage(getToolRadioBoxImage())

def getToolRadioBoxImage():
    stream = cStringIO.StringIO(getToolRadioBoxData())
    return wxImageFromStream(stream)

def getToolRadioBoxIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolRadioBoxBitmap())
    return icon

#----------------------------------------------------------------------
def getToolComboBoxData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x0c$\xbf\x95\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\xc3IDATx\x9c\xb5\x94\xc1\r\xc3 \x0cE\x7f+\x1f<\n\xa3\xe4\xd0\x03\
\x83\xf4\x90q\x18\x83\x11\x18!\x87\x1e\x18\x85C\xa4\xf6\x04\n\x01SH\xe9\x93P\
$\xb0\xfe\xc76\xce\xcdZ\xfbF\x07\xcbc\xe9\t\xcb`b\x10\x00h\xad\x9b\x81a\x0f\
\x00\x00\xef\xfd\xb0\t\x9dEf\xe1\x9c\x03\x00\xdc\xa7\xaaV\xa8\x1a0\xf14\x03\
\xfa\x1e\x92\xa3\x94\x12\xcf\x8c1X\x9f+\xb6\xd7&\x1b01\xc2\x1e\xd2\xf7\x8c\
\xf7\x1eJ\xa9\xa2\xe1\xce\xb9B\x1c\xb8\xd8\x83hr\xa4&^\x18\x1co\x1d\xb3\xe8!\
\xbe\x98\x1aE\x06L\x9cV\x8b\x98\x85T\x9aH\xea\x81Tsi?\x9a\xb4\xc4\xab\x19\
\x8c\xd2\x12\xcf\x0c\xa4[\xfe:\xe1\x7f\x9f\xe4\xe1Ak\xbd\x18\xd1\xa0\xa7\x0c\
W\x7f\x1f\x1f\x92\xc6Yif\xadRe\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolComboBoxBitmap():
    return wxBitmapFromImage(getToolComboBoxImage())

def getToolComboBoxImage():
    stream = cStringIO.StringIO(getToolComboBoxData())
    return wxImageFromStream(stream)

def getToolComboBoxIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolComboBoxBitmap())
    return icon

#----------------------------------------------------------------------
def getToolListBoxData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x16\x00\x00\x00\x18\x08\x06\
\x00\x00\x00\xfe\xbe\rK\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x91IDATx\x9c\xe5\x95=\n\xc0 \x0c\x85_\x8b\x83\x87\xed\xe0Q\x1cz8\
\x8f\x92Ah\x87"H1\xa21:\xb4o\xf3\x87\xe7\xe3\x8b!\x9b?\xfd\x85\t2\x00\xe0\
\x0e\xa7jJ\x91\x1e\xe3\xb4\xd0P\x08\x01\x00\xb0\xd7.Yc\xc5\x0fT\x8dG\xc4\x1a\
[cA\x91\xc4\xa9\xd7&Ni\x01\x88S\x1b\xee`\xa4pE\xe3<m\xcb>\xa7u\x8c\xb9T\xbd\
\rTd\xfc\xe6+\xe9J\xb6x\xb9Y/_`"\xe3\xa6\xef\xf6\x0f\x14\x1fa\xac1M\xe6\xa3H\
\xb3J\xd5Xk\x90\xe6\xba\x01\xea\xbe>\xf3\x9d/\x83Q\x00\x00\x00\x00IEND\xaeB`\
\x82' 

def getToolListBoxBitmap():
    return wxBitmapFromImage(getToolListBoxImage())

def getToolListBoxImage():
    stream = cStringIO.StringIO(getToolListBoxData())
    return wxImageFromStream(stream)

def getToolListBoxIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolListBoxBitmap())
    return icon

#----------------------------------------------------------------------
def getToolStaticLineData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x14\x00\x00\x00\x02\x08\x06\
\x00\x00\x00X\x06\xfc\x8b\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x19IDATx\x9cc\x9c0e\xc2\x7f\x06*\x81\x8c\x8c\x0c\x06\x16\x18\x83Z\
\x00\x00rP\x05)\xab\x92\xb7?\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolStaticLineBitmap():
    return wxBitmapFromImage(getToolStaticLineImage())

def getToolStaticLineImage():
    stream = cStringIO.StringIO(getToolStaticLineData())
    return wxImageFromStream(stream)

def getToolStaticLineIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolStaticLineBitmap())
    return icon

#----------------------------------------------------------------------
def getToolStaticBitmapData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x0e\x00\x00\x00\x11\x08\x06\
\x00\x00\x00\xed\xc8\x9d\x9f\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\
\x00\x00\x01\xceIDATx\x9c}\x93\x9f\x93#A\x14\x80\xbf\xa4\x06\x1a\x0e\x1e\x04\
\x1a\x03\x07\xf9\x13\x02\x07\x03\x07\x03\x07\x81\x85\xc0\xe1\xc2\xc2\xc1\xc0\
A\xe0 8\xb0\x10X\x08\x0e,\x04\x16\x02\x0b\x07\x07\x81\x85\x81\x85\x81\xc0\
\xc0A`\xa1!\xd0\x10x\xd0U}\x90\x9d\xb9ds{\xaf\xaa\xab\xba_\xbf\xaf\xdf\xcf\
\xee\x89\x08\xa7\xe2\xf6.\xf2\x0f\xb1\x03\xdb;=\xf7O\x81\x16\xd2\x83R?\xd7x\
\xef\xdf}\xb0\'"\x9d\xb2z\xaaX?\x94\xcc\xf2\x11&1\xe8A\xa9\xb6\x9e\xd5cMY\
\xae\xcf<w`\xf5Ta\xadA\xd8 v\x0c\x08h\x85\x06\xc5\xef=\xb3\xa2\xa1\xbc/;\xb8\
\xdfz[\xdc-\xb0\xc9\x06\x19\xa4\x90\x0c!\x11\xf8\x90a\x12\x83\x880\xbb\xb6L\
\xaf\xa6]\xa8I\xbb\xc9\xaf30\x80\xb1GEP\x004\x18L\xa2\xc8\xc0 b\xba|\xbb\xe2\
\xa8jg\x0c\x06\x12A\xf5X\x1c\xc5@b\xb0\xd2\xdeC\xbfM\xb6\xb8[\xbf\x82\n\xc1\
\x83\xee \xb8\xa3.(\xea=\xab\x87\xcde;\x96\xcb%\x1a^CL\x0c\xaa;\xc0CP\x9cs\
\xec^<\xf3b\xd1\x15\xa7\xcb\xd1\x18\x83Q\x05\x0cz\xd8A\xf0\xa8z\x9cs\xe8A)\
\x96\r?\x7f-\xcf\xfb\x080\xfd:\x89u\xb5a\xf8q\xc4\xe2G\x8a\xf7\x9e\xdd\x8bc~\
\xbbA\x06#\xd6\x8f\xe7}DD\x10\x11H\x88\x93\xab,\xd6\xdb:V\xd5&f_\xd2\x98\x7f\
\x9b\xc6\xa6i\xa2\x06\x8d\x1a4\xb6\xb6"\xf2\x17\x9cL\xb2\xa8Ac\xf5\\\xc5\xf4\
s\x1a\xf3\xefyt{w\x01\xb4\xab\'"\x18cby_\xb2\xb8-\xc8\xb2\x8c\xe6\xf7\x8e\
\xd5j\x05\x81\xb3\xc1>\x95>\x80s\x8e\xa2\x98ss\x933\xfe\x94\xd2l\x1b\xde\xfe\
\x9a\xb7\xd2\x15\xc7{\x1f\x87C\x8b\xb5\x96\xf18\xa5,\xcbw\xbd]\x80\xd6\xcaq\
\x820\xff\x85\x00\xfe\x00df\xf8-\xfbB\xb7\xb6\x00\x00\x00\x00IEND\xaeB`\x82'\
 

def getToolStaticBitmapBitmap():
    return wxBitmapFromImage(getToolStaticBitmapImage())

def getToolStaticBitmapImage():
    stream = cStringIO.StringIO(getToolStaticBitmapData())
    return wxImageFromStream(stream)

def getToolStaticBitmapIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolStaticBitmapBitmap())
    return icon

#----------------------------------------------------------------------
def getToolSliderData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x0e\x08\x06\
\x00\x00\x005\xf8\xdc~\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\x80IDATx\x9c\xdd\x92\xb1\r\x800\x10\x03\x0f\x94"#Q0PF\xc8\x08\x19\xcbcd\
\x94\x14HP \x84\x04\x08>\n4\xb8\xfcO|\xd6\xcb]Ji\xe6C9\x80\x18\xe3\'\xe6e*+\
\x00@\x12\xc38\x98>z\xe7\x91dz\xeb\x8e\x83\x9c\xb31\x9fM\xfd\xddR\xd2)\xa95\
\xb9\t\x00\x10B\xa82\xac\x06\xb4\xea\xe7\x80\xd6\xfb\xc3EMaoJmc\x1e\x01\xde\
\xf9f\xc3[\xc0\x1b\x89/\x01e*\xaf\x1boZ\x00\xcau!\xcd\n\x1f\x13Q\x00\x00\x00\
\x00IEND\xaeB`\x82' 

def getToolSliderBitmap():
    return wxBitmapFromImage(getToolSliderImage())

def getToolSliderImage():
    stream = cStringIO.StringIO(getToolSliderData())
    return wxImageFromStream(stream)

def getToolSliderIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolSliderBitmap())
    return icon

#----------------------------------------------------------------------
def getToolGaugeData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x0e\x08\x06\
\x00\x00\x005\xf8\xdc~\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00cIDATx\x9cc\x9c0e\xc2\x7f\x06\x1a\x02\x16\x06\x06\x06\x86\x82\x9c\x02\
\x9a\x18\xfe\xe3\xcf\x0f\x88\x050\x0e.\xc0\xc1\xc2\xc1p\xe1\xca\x05\xb2,aA\
\xe6|x\xf3\x81,C\xf0\x01&B\nv\xec\xd9A[\x0b(\x05\xa3\x16\x0c\xbc\x05,\xe8\
\x02\x94\xa6\x1a\x9c\x16p\xb0pP\xd5`\x0c\x0b\xc8\xcd\xa9DY\x80\xaf\x98\xa0\
\x14\x00\x00+\xec\x19!J\x0e\x8b\xa6\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolGaugeBitmap():
    return wxBitmapFromImage(getToolGaugeImage())

def getToolGaugeImage():
    stream = cStringIO.StringIO(getToolGaugeData())
    return wxImageFromStream(stream)

def getToolGaugeIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolGaugeBitmap())
    return icon

#----------------------------------------------------------------------
def getToolScrollBarData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\r\x00\x00\x00\x18\x08\x06\
\x00\x00\x00!\xf0wT\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xd1IDATx\x9c\xa5\x94\xb1\r\x830\x10E_"\x17\x1e\x85\x11\\P\xdc@)(\x19\
\x81\x92"\x05\xe3PPx\x04\x0f\x91\x82\x92"RR P8l\xcb(\xaf\x04\x1e\xff\xfc\x0f\
q\xeb\xba\xee\xc3E\x0c@\xdb\xb6\xc5\xc2\xf2^V\t`\x1c\xc7\xc3MW;\xfc\xe4\xa3\
\xe2=v\xd1\xd5\x8e\x10\x02"R&m\x02@\xff\xec\xa3\xe2=%\x00\x88HT4(\xf4\xd9b\
\xec\x92\xab\x1d\xd6\xd8\xe4\x83"\xb2\xbfp\x97\xfc\xe4\x8bRNI9\xac\xb1\xe7$\
\xe0PB\x8e\xe8\x9e4z\xec"I\xf3_\xe5\xb9\xba\x93Ri\xdd\x07)W\xf90\x0c4\x8f&\
\xbe\\\xfd\xedm\x13\xfc\n\xa0\xda\xf3\x93\xa7\xaa\xaa\x83\xa4\x85\x93\xa4I\
\x9d\xf3$mi\xb1\xb1\xb2I!\x84\xa4\x90\x94\xe6\xd7\x9c]\x81\x81\xf5\x0fs\x85/\
K\xf5c\xf9\x89\xca\xe1|\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolScrollBarBitmap():
    return wxBitmapFromImage(getToolScrollBarImage())

def getToolScrollBarImage():
    stream = cStringIO.StringIO(getToolScrollBarData())
    return wxImageFromStream(stream)

def getToolScrollBarIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolScrollBarBitmap())
    return icon

#----------------------------------------------------------------------
def getToolTreeCtrlData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00aIDATx\x9c\xed\x93\xcb\r\xc00\x08C\xa1\xea\x00\x1e\x83\xfd\xa7a\x0c6Ho\
\x88"\x88\x1aq\xado|l\xf1"\x85\x01\xd0Dw\xd54\xb3\x15k\x00\xdc\x06\x88\xc8kY\
U\xdb\xe5J\x0c\x80Dd\x9d\x1a\xfd\x82n\x901\xa2"\x92\x07D\x94\x93k< \x9bv\x0f\
W\x06d\xfd\x08\xdf\x11x\xfa\x17\xae\x91\x9b\x88\x1e\xba\x12*2\xab=\t\xe9\x00\
\x00\x00\x00IEND\xaeB`\x82' 

def getToolTreeCtrlBitmap():
    return wxBitmapFromImage(getToolTreeCtrlImage())

def getToolTreeCtrlImage():
    stream = cStringIO.StringIO(getToolTreeCtrlData())
    return wxImageFromStream(stream)

def getToolTreeCtrlIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolTreeCtrlBitmap())
    return icon

#----------------------------------------------------------------------
def getToolListCtrlData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x16\x00\x00\x00\x18\x08\x06\
\x00\x00\x00\xfe\xbe\rK\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00}IDATx\x9cc\x9c0e\xc2\x7f\x06\x1a\x00\x16\x06\x06\x06\x86\x82\x9c\
\x02\xaa\x1a\xfa\xe3\xcf\x0f\x88\xc10\x0e5\xc0\x8d\x1b7\x18\x18\x18\x18\x18\
\x98\xa8b\x1a\x16\xc0\x82M\x90\x03\x87bR\xfcD3\x17\x8f\x1aL{\x83\xb1\xa6\nj\
\xa4\xe8\xa1\x17\x14\x04\r\xe6\xc0\x99](0\x18f(9\x86\xe34\x18\xdd0R\r\xa7o\
\x18\xe3r\x1d)\xae\xa6w\x06\xa1<\x8b\x0c\xbd\x0c\x02\x0f\nX]EU\x83\xa9U\x91"\
\x03\x00\x9c{\x16ip\xfa\xbe\x9c\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolListCtrlBitmap():
    return wxBitmapFromImage(getToolListCtrlImage())

def getToolListCtrlImage():
    stream = cStringIO.StringIO(getToolListCtrlData())
    return wxImageFromStream(stream)

def getToolListCtrlIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolListCtrlBitmap())
    return icon

#----------------------------------------------------------------------
def getToolCheckListData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x18\x08\x06\
\x00\x00\x00\xe0w=\xf8\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xcdIDATx\x9c\xdd\x951\x0e\xc3 \x0cE\x7f+\x0f\x1c\xb6C\x8e\x92\xa1\x07\
\xcb\xd0\x81\xa30Dj\x87\x8a\x8a\x82\xbfqhX\xfa\xa5\x0c\xd8\xc1\xcf61\xb9\xac\
\xf7\xf5\x89\x89\x12\x00Xn\xcb\x94\xe0iOo@^\x9c\xa9\x18#\x00\xe0Z;\x82\x04\
\x04\t\xea&\xe6c\xef\xab\x00\x80W3R\xa5\n\x00\xda\xac\xac\xaa\xd2\x9e\xa8\
\x9f\x02\xcaM9\xc8\x88(\xa0\x84\xb0\xe0\xa5\x8fU!\x8dE\t\xd0\x83X\xa2\x00-\
\xbb\x12\xc2\xa0\xb5\xdd<\x03k\xed\x95\n\xb0\xbe\x98\x1e\xb0\xb67-\xb22\x1d\
\xa9\xa2\x01\xe4,\xeb~3[\x0f\xee\x9ad\xab\x1d\xf99<hg\xc9\x9c\x83\x9e<\x87\
\xfe\x13\xc03\x17\xd3[\xf4\xa7g\xa0\xdd;\xb5\xbcC\xf7\x01\xe4\x7f\xe8\xf6\
\xd8\xbe\xd6\xcc\xe6\x95\x1c\xc9fD/\xb2\x10\x87\xc3dJ"U\x00\x00\x00\x00IEND\
\xaeB`\x82' 

def getToolCheckListBitmap():
    return wxBitmapFromImage(getToolCheckListImage())

def getToolCheckListImage():
    stream = cStringIO.StringIO(getToolCheckListData())
    return wxImageFromStream(stream)

def getToolCheckListIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolCheckListBitmap())
    return icon

#----------------------------------------------------------------------
def getToolNotebookData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x18\x08\x06\
\x00\x00\x00\xe0w=\xf8\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00\xd8IDATx\x9c\xed\x96!\x12\x830\x10E\x7f:\x11\xc8\x88\n\x8e\x80\xa8\xe0\
\x08\x1c=\xa2"\x12Q\x91#D \x90\x88\xceP\x95N\x12\x92\xb0K\x87\x8aN\x9f\xdb\
\xcdN\xfe\xfeea\x10J)\xb8\xc9\xad \xd0^[A\xa9\x0b\x91nr\xab\xb5\x96T<\xcf\
\xf3\xaa\x94b\x89\xc8\\\xb2\xbf\xf5\x18\x1fc\x94\xd3Z\x03\xc0\xae\xdb\xd4eV\
\xa0\x86\xb9\x9b\xeay\xear#\xe0\xbb\xcf\xb9\xf0\x0c\xc3\x10\xc5\xde\x9d1[q\
\xb6\x83\xf4R/\x18\xc6!\x970\x08\xbb\xf6.>%;"\n\xe1\x98J\xddG\x02\xa5\x99\
\x97\xf2\x87Ft\x06o\x81\xd2\xc6\x94\xf2T\x0eo\x11\xfb\x19p\xa8]\x98"\x96\xe7\
B\xfe\x16\x01@\xd7u\xe4\xdaF6|\x07\x9cf\x80\x13\xb7\xc8\x8f\xf1{k\xfa\x17\
\xf8]\x01\t\xf0\xdeL.\x02\x00\xe9\x97\xe5(/\x90\xf2\\\xdd\xe7\xbb{_\x00\x00\
\x00\x00IEND\xaeB`\x82' 

def getToolNotebookBitmap():
    return wxBitmapFromImage(getToolNotebookImage())

def getToolNotebookImage():
    stream = cStringIO.StringIO(getToolNotebookData())
    return wxImageFromStream(stream)

def getToolNotebookIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolNotebookBitmap())
    return icon

#----------------------------------------------------------------------
def getToolSpinCtrlData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x18\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x0c$\xbf\x95\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\xebIDATx\x9c\xad\x94\xbd\x11\x84 \x10\x85\x1f7\x06\x86\x1b\x18P\x82\
eX\x90\x01\x05\\p%\x18\x18X\x8eeP\x02\x81\xc1\x86\x04\xcep\xc1\x1d\xce\xc9\
\x00\x87?o\x86dY\xdf\xe7\xee\x02b\x18\x07\x87\x13z=_\xa2(\xf1\x0b8\xb4\xecj\
\x1d\x11!\\\xb1x\xe5Av\xb5E?\xa4\xb5\x8e\xc6\xcdb\x9c\xd6\x1a\xcc\xec\x88h\
\xab\xeeQ\xe4\xfaG\xde\x1c\x00\x86q\x003omO\x02\xea\xaa>l\x0e\x00]\xd7\xed U\
\xec\xa3Rs\xafy\x9e\x93{Q\x80]m\x11\xc4,\xc6\xe5\xf2\x98\xd9E\x01\xa5\x92\
\x8d\x14D\x94\xcd\xb9e\xc89]\xaa\xc0,&yI\xa7i\x82\xea\xd55\x80l\xa4\x08O\x11\
\xf0\x19\xba\xea\x15\x88H\\n\x91l\xa4h\xdbv\x17\xf3\xe6@f\x06\xa57;Txdo\x19\
\xb2\xaf\xe2\xb75~o\x9bA\xea\x8d9\x02\t\xdf\xa1\rp\xb6\x1d\xa1Bs\x00x\x03\
\xf8\x1fx\xe7\xcd\xa8y\xd6\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolSpinCtrlBitmap():
    return wxBitmapFromImage(getToolSpinCtrlImage())

def getToolSpinCtrlImage():
    stream = cStringIO.StringIO(getToolSpinCtrlData())
    return wxImageFromStream(stream)

def getToolSpinCtrlIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolSpinCtrlBitmap())
    return icon

#----------------------------------------------------------------------
def getToolUnknownData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00dIDATx\x9ccd``\xf8\xcf@\x01`a```\xb8p\xe5\x02Y\x9a\rt\x0c \x06\xe0\
\x92D\x06\xb8,a"F3.1\x9c\x06 \xdbJ\xc8{x\r \x06`\r\x03R\x02\x95\xa0\x0b`~\')\
\x10\xd15S\xe4\x02|\xb6\x13m\x00>\x803!\x11\xb2\x99(\x17\x18\xe8\x18\x10\x0c\
\x87\x81\xf7\x02#\x03\x85\xd9\x19\x00\x180\x1c\x9b3;\xb6\xda\x00\x00\x00\x00\
IEND\xaeB`\x82' 

def getToolUnknownBitmap():
    return wxBitmapFromImage(getToolUnknownImage())

def getToolUnknownImage():
    stream = cStringIO.StringIO(getToolUnknownData())
    return wxImageFromStream(stream)

def getToolUnknownIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolUnknownBitmap())
    return icon

#----------------------------------------------------------------------
def getToolBoxSizerData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00DIDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4\x9b\x1a\x06\xb00000\x04\x84\
\x04\xfc\xa7\xc8\x00\x06\x06\x06\x86\rk60bS\x10\x10\x12\xf0\x1f\x9f\xdc\xc0\
\x87\xc1\xa8\x01T0\x80Q@@\x80\xa2\x84\xc48\xf43\x13\x00\xf5\xfe\x0c\x98\x979\
f\xc6\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolBoxSizerBitmap():
    return wxBitmapFromImage(getToolBoxSizerImage())

def getToolBoxSizerImage():
    stream = cStringIO.StringIO(getToolBoxSizerData())
    return wxImageFromStream(stream)

def getToolBoxSizerIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolBoxSizerBitmap())
    return icon

#----------------------------------------------------------------------
def getToolSeparatorData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x0e\x00\x00\x00\x02\x08\x06\
\x00\x00\x00h\x8a\xed\xaa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00\x19IDATx\x9cc\x9c0e\xc2\x7f\x06\x12AFF\x06\x03\x0b\x8cA*\x00\x00\
\xb5q\x05)B\x17\xc1\x07\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolSeparatorBitmap():
    return wxBitmapFromImage(getToolSeparatorImage())

def getToolSeparatorImage():
    stream = cStringIO.StringIO(getToolSeparatorData())
    return wxImageFromStream(stream)

def getToolSeparatorIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolSeparatorBitmap())
    return icon

#----------------------------------------------------------------------
def getToolStaticBoxSizerData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00dIDATx\x9c\xed\x92A\n\xc00\x08\x045\xe4\x01\xfb4\x0f>3\x07\x9f\xe6\
\x0f\xecU,\xb4IS\xe8\xa5s\x11\x16\x1c\x16\x91\x01\xd0\x0e\xad\x06\xee\x1e\
\x8f\x05\xee\x1e\x00xE\xd2\x89\x88D%l\x18\xd7\x06\xa2r+\xea5\xc8\rl\x18gyET\
\xa2\xd5\xe5<g8\x1dq\x95_\xf0\x82\x80\x01L=\xcc\xa5`\x87\xefop\x00N\x12$g%t;\
\xe1\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolStaticBoxSizerBitmap():
    return wxBitmapFromImage(getToolStaticBoxSizerImage())

def getToolStaticBoxSizerImage():
    stream = cStringIO.StringIO(getToolStaticBoxSizerData())
    return wxImageFromStream(stream)

def getToolStaticBoxSizerIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolStaticBoxSizerBitmap())
    return icon

#----------------------------------------------------------------------
def getToolGridSizerData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x08\x06\
\x00\x00\x00\x1f\xf3\xffa\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\
\x00\x00<IDATx\x9cc\x14\x10\x10`\x08\x08\t\xf8\xcf@&`\x8116\xac\xd9\xc0\x88M\
A@H\xc0\x7f|rL\xe4\xda\x0c\x03\xa3\x06000\x8eF\xe3p0\x80\xe2hd\x14\x10\x10\
\xa0\xc8\x05\x00M\x98\x16\xba|O\xcc\x02\x00\x00\x00\x00IEND\xaeB`\x82' 

def getToolGridSizerBitmap():
    return wxBitmapFromImage(getToolGridSizerImage())

def getToolGridSizerImage():
    stream = cStringIO.StringIO(getToolGridSizerData())
    return wxImageFromStream(stream)

def getToolGridSizerIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getToolGridSizerBitmap())
    return icon

#----------------------------------------------------------------------
def getTreeSeparatorData():
    return \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10\x00\x00\x00\x0e\x08\x06\
\x00\x00\x00&/\x9c\x8a\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x007IDATx\x9cc\x14\x10\x10`\xa0\x040Q\xa4{\xd4\x00\x06\x06\x06\x06\x06\x16\
\x18\xa3\xa1\xa5\xe1?\xb1\x9a222\x18$D$\x18Q\x0c\x80I\x90\n\x18G\xd3\xc1 0\
\x00\x00\xfb\xe8\x05\xb7\x9e\n\x8b\xdd\x00\x00\x00\x00IEND\xaeB`\x82' 

def getTreeSeparatorBitmap():
    return wxBitmapFromImage(getTreeSeparatorImage())

def getTreeSeparatorImage():
    stream = cStringIO.StringIO(getTreeSeparatorData())
    return wxImageFromStream(stream)

def getTreeSeparatorIcon():
    icon = wxEmptyIcon()
    icon.CopyFromBitmap(getTreeSeparatorBitmap())
    return icon




# shell.py
"""wxPython interactive shell

Copyright (c) 1999 SIA "ANK"

this module is free software.  it may be used under same terms as Python itself

Notes:
i would like to use command completion (see rlcompleter library module),
but i cannot load it because i don't have readline...

History:
03-oct-1999 [als] created
04-oct-1999 [als] PyShellOutput.intro moved from __init__ parameters
                  to class attributes; html debug disabled
04-oct-1999 [als] fixed bug with class attributes
                  input prompts and output styles added to customized demo
                  some html cleanups
04-oct-1999 [rpd] Changed to use the new sizers
05-oct-1999 [als] changes inspired by code.InteractiveInterpreter()
                  from Python Library.  if i knew about this class earlier,
                  i would rather inherit from it.
                  renamed to wxPyShell.py since i've renounced the 8.3 scheme

8-10-2001         THIS MODULE IS NOW DEPRECATED.  Please see the most excellent
                  PyCrust package instead.

"""
__version__ ="$Revision: 1.5.2.2 $"
# $RCSfile: shell.py,v $

import sys, code, traceback
from wxPython.wx import *
from wxPython.html import *


class PyShellInput(wxPanel):
    """PyShell input window

    """
    PS1 =" Enter Command:"
    PS2 ="... continue:"
    def __init__(self, parent, shell, id=-1):
        """Create input window

        shell must be a PyShell object.
        it is used for exception handling, eval() namespaces,
        and shell.output is used for output
        (print's go to overridden stdout)
        """
        wxPanel.__init__(self, parent, id)
        self.shell =shell
        # make a private copy of class attrs
        self.PS1 =PyShellInput.PS1
        self.PS2 =PyShellInput.PS2
        # create controls
        self.label =wxStaticText(self, -1, self.PS1)
        tid =wxNewId()
        self.entry =wxTextCtrl(self, tid, style = wxTE_MULTILINE)
        EVT_CHAR(self.entry, self.OnChar)
        self.entry.SetFont(wxFont(9, wxMODERN, wxNORMAL, wxNORMAL, False))
        sizer =wxBoxSizer(wxVERTICAL)
        sizer.AddMany([(self.label, 0, wxEXPAND), (self.entry, 1, wxEXPAND)])
        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        EVT_SET_FOCUS(self, self.OnSetFocus)
        # when in "continuation" mode,
        # two consecutive newlines are required
        # to avoid execution of unfinished block
        self.first_line =1

    def OnSetFocus(self, event):
        self.entry.SetFocus()


    def Clear(self, event=None):
        """reset input state"""
        self.label.SetLabel(self.PS1)
        self.label.Refresh()
        self.entry.SetSelection(0, self.entry.GetLastPosition())
        self.first_line =1
        # self.entry.SetFocus()

    def OnChar(self, event):
        """called on CHARevent.  executes input on newline"""
        # print "On Char:", event.__dict__.keys()
        if event.KeyCode() !=WXK_RETURN:
            # not of our business
            event.Skip()
            return
        text =self.entry.GetValue()
        # weird CRLF thingy
        text = text.replace("\r\n", "\n")
        # see if we've finished
        if (not (self.first_line or text[-1] =="\n")  # in continuation mode
            or (text[-1] =="\\")  # escaped newline
          ):
            # XXX should escaped newline put myself i "continuation" mode?
            event.Skip()
            return
        # ok, we can try to execute this
        rc =self.shell.TryExec(text)
        if rc:
            # code is incomplete; continue input
            if self.first_line:
                self.label.SetLabel(self.PS2)
                self.label.Refresh()
                self.first_line =0
            event.Skip()
        else:
            self.Clear()

class PyShellOutput(wxPanel):
    """PyShell output window

    for now, it is based on simple wxTextCtrl,
    but i'm looking at HTML classes to provide colorized output
    """
    # attributes for for different (input, output, exception) display styles:
    # begin tag, end tag, newline
    in_style =(" <font color=\"#000080\"><tt>&gt;&gt;&gt;&nbsp;",
               "</tt></font><br>\n", "<br>\n...&nbsp;")
    out_style =("<tt>", "</tt>\n", "<br>\n")
    exc_style =("<font color=\"#FF0000\"><tt>",
                "</tt></font>\n", "<br>\n")
    intro ="<H3>wxPython Interactive Shell</H3>\n"
    html_debug =0
    # entity references
    erefs =(("&", "&amp;"), (">", "&gt;"), ("<", "&lt;"), ("  ", "&nbsp; "))
    def __init__(self, parent, id=-1):
        wxPanel.__init__(self, parent, id)
        # make a private copy of class attrs
        self.in_style =PyShellOutput.in_style
        self.out_style =PyShellOutput.out_style
        self.exc_style =PyShellOutput.exc_style
        self.intro =PyShellOutput.intro
        self.html_debug =PyShellOutput.html_debug
        # create windows
        if self.html_debug:
            # this was used in html debugging,
            # but i don't want to delete it; it's funny
            splitter =wxSplitterWindow(self, -1)
            self.view =wxTextCtrl(splitter, -1,
                       style = wxTE_MULTILINE|wxTE_READONLY|wxHSCROLL)
            self.html =wxHtmlWindow(splitter)
            splitter.SplitVertically(self.view, self.html)
            splitter.SetSashPosition(40)
            splitter.SetMinimumPaneSize(3)
            self.client =splitter
        else:
            self.view =None
            self.html =wxHtmlWindow(self)
            self.client =self.html  # used in OnSize()
        self.text =self.intro
        self.html.SetPage(self.text)
        self.html.SetAutoLayout(True)
        self.line_buffer =""
        # refreshes are annoying
        self.in_batch =0
        self.dirty =0
        EVT_SIZE(self, self.OnSize)
        EVT_IDLE(self, self.OnIdle)

    def OnSize(self, event):
        self.client.SetSize(self.GetClientSize())

    def OnIdle(self, event):
        """when there's nothing to do, we can update display"""
        if self.in_batch and self.dirty: self.UpdWindow()

    def BeginBatch(self):
        """do not refresh display till EndBatch()"""
        self.in_batch =1

    def EndBatch(self):
        """end batch; start updating display immediately"""
        self.in_batch =0
        if self.dirty: self.UpdWindow()

    def UpdWindow(self):
        """sync display with text buffer"""
        html =self.html
        html.SetPage(self.text)
        self.dirty =0
        # scroll to the end
        (x,y) =html.GetVirtualSize()
        html.Scroll(0, y)

    def AddText(self, text, style=None):
        """write text to output window"""
        # a trick needed to defer default from compile-time to execute-time
        if style ==None: style =self.out_style
        if 0 and __debug__: sys.__stdout__.write(text)
        # handle entities
        for (symbol, eref) in self.erefs:
            text = text.replace(symbol, eref)
        # replace newlines
        text = text.replace("\n", style[2])
        # add to contents
        self.text =self.text +style[0] +text +style[1]
        if not self.in_batch: self.UpdWindow()
        else: self.dirty =1
        if self.html_debug:
            # html debug output needn't to be too large
            self.view.SetValue(self.text[-4096:])

    def write(self, str, style=None):
        """stdout-like interface"""
        if style ==None: style =self.out_style
        # do not process incomplete lines
        if len(str) <1:
            # hm... what was i supposed to do?
            return
        elif str[-1] !="\n":
            self.line_buffer =self.line_buffer +str
        else:
            self.AddText(self.line_buffer +str, style)
            self.line_buffer =""

    def flush(self, style=None):
        """write out all that was left in line buffer"""
        if style ==None: style =self.out_style
        self.AddText(self.line_buffer +"\n", style)

    def write_in(self, str, style=None):
        """write text in "input" style"""
        if style ==None: style =self.in_style
        self.AddText(str, style)

    def write_exc(self, str, style=None):
        """write text in "exception" style"""
        if style ==None: style =self.exc_style
        self.AddText(str, style)

class PyShell(wxPanel):
    """interactive Python shell with wxPython interface

    """
    def __init__(self, parent, globals=globals(), locals={},
                 id=-1, pos=wxDefaultPosition, size=wxDefaultSize,
                 style=wxTAB_TRAVERSAL, name="shell"):
        """create PyShell window"""
        wxPanel.__init__(self, parent, id, pos, size, style, name)
        self.globals =globals
        self.locals =locals
        splitter =wxSplitterWindow(self, -1)
        self.output =PyShellOutput(splitter)
        self.input =PyShellInput(splitter, self)
        self.input.SetFocus()
        splitter.SplitHorizontally(self.input, self.output)
        splitter.SetSashPosition(100)
        splitter.SetMinimumPaneSize(20)
        self.splitter =splitter
        EVT_SET_FOCUS(self, self.OnSetFocus)
        EVT_SIZE(self, self.OnSize)

    def OnSetFocus(self, event):
        self.input.SetFocus()

    def TryExec(self, source, symbol="single"):
        """Compile and run some source in the interpreter.

        borrowed from code.InteractiveInterpreter().runsource()
        as i said above, i would rather like to inherit from that class

        returns 1 if more input is required, or 0, otherwise
        """
        try:
            cc = code.compile_command(source, symbol=symbol)
        except (OverflowError, SyntaxError):
            # [als] hm... never seen anything of that kind
            self.ShowSyntaxError()
            return 0
        if cc is None:
            # source is incomplete
            return 1
        # source is sucessfully compiled
        out =self.output
        # redirect system stdout to the output window
        prev_out =sys.stdout
        sys.stdout =out
        # begin printout batch (html updates are deferred until EndBatch())
        out.BeginBatch()
        out.write_in(source)
        try:
            exec cc in self.globals, self.locals
        except SystemExit:
            # SystemExit is not handled and has to be re-raised
            raise
        except:
            # all other exceptions produce traceback output
            self.ShowException()
        # switch back to saved stdout
        sys.stdout =prev_out
        # commit printout
        out.flush()
        out.EndBatch()
        return 0

    def ShowException(self):
        """display the traceback for the latest exception"""
        (etype, value, tb) =sys.exc_info()
        # remove myself from traceback
        tblist =traceback.extract_tb(tb)[1:]
        msg = ' '.join(traceback.format_exception_only(etype, value)
                        +traceback.format_list(tblist))
        self.output.write_exc(msg)

    def ShowSyntaxError(self):
        """display message about syntax error (no traceback here)"""
        (etype, value, tb) =sys.exc_info()
        msg = ' '.join(traceback.format_exception_only(etype, value))
        self.output.write_exc(msg)

    def OnSize(self, event):
        self.splitter.SetSize(self.GetClientSize())

#----------------------------------------------------------------------
if __name__ == '__main__':
    class MyFrame(wxFrame):
        """Very standard Frame class. Nothing special here!"""
        def __init__(self, parent=NULL, id =-1,
                     title="wxPython Interactive Shell"):
            wxFrame.__init__(self, parent, id, title)
            self.shell =PyShell(self)

    class MyApp(wxApp):
        """Demonstrates usage of both default and customized shells"""
        def OnInit(self):
            frame = MyFrame()
            frame.Show(True)
            self.SetTopWindow(frame)
##             PyShellInput.PS1 =" let's get some work done..."
##             PyShellInput.PS2 =" ok, what do you really mean?"
##             PyShellOutput.in_style =(
##                 "<I><font color=\"#008000\"><tt>&gt;&gt;&gt;&nbsp;",
##                 "</tt></font></I><br>\n", "<br>\n...&nbsp;")
##             PyShellOutput.out_style =(
##                 "<font color=\"#000080\"><tt>",
##                 "</tt></font><br>\n", "<br>\n")
##             PyShellOutput.exc_style =("<B><font color=\"#FF0000\"><tt>",
##                 "</tt></font></B>\n", "<br>\n")
##             PyShellOutput.intro ="<I><B>Customized wxPython Shell</B>" \
##                 "<br>&lt;-- move this sash to see html debug output</I><br>\n"
##             PyShellOutput.html_debug =1
##             frame = MyFrame(title="Customized wxPython Shell")
##             frame.Show(True)
            return True

    app = MyApp(0)
    app.MainLoop()




"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: wx_.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


_topics = {
    'Accelerators': None,
    'App': None,
    'Base': None,
    'ClipDragDrop': None,
    'Config': None,
    'Controls': None,
    'DataStructures': None,
    'DateTime': None,
    'Dialogs': None,
    'Drawing': None,
    'Errors': None,
    'EventFunctions': None,
    'Events': None,
    'FileSystem': None,
    'Frames': None,
    'Functions': None,
    'Help': None,
    'ImageHandlers': None,
    'Joystick': None,
    'LayoutConstraints': None,
    'Logging': None,
    'Menus': None,
    'MimeTypes': None,
    'Misc': None,
    'Panel': None,
    'Printing': None,
    'Process': None,
    'SashSplitter': None,
    'Sizers': None,
    'Streams': None,
    'Threading': None,
    'ToolBar': None,
    'Tree': None,
    'Validators': None,
    'Window': None,
    }

for topic in _topics.keys():
    _topics[topic] = __import__(topic, globals())
    exec 'from %s import *' % topic

del topic  # Cleanup the namespace.

try:
    del wx  # Cleanup any module that imports Parameters as wx.
except:
    pass
